/*
 * 10/17/2003 - 13:44:37
 * 
 * MLDPanel.java - Copyright (C) 2003 Dreux Loic dreuxl@free.fr
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA.
 */

package org.eucalyptus.analysesi.gui.mld;

import java.awt.BorderLayout;

import javax.swing.JComponent;
import javax.swing.JToolBar;
import javax.swing.UIManager;

import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.eucalyptus.analysesi.gui.AnalyseSIPanel;
import org.eucalyptus.analysesi.gui.dictionary.DictionaryPanel;
import org.eucalyptus.analysesi.gui.event.AnalyseSIEvent;
import org.eucalyptus.analysesi.gui.event.AnalyseSIListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


public class MLDPanel extends AnalyseSIPanel implements AnalyseSIListener {
	@SuppressWarnings("unused")
	private static Logger logger = LoggerFactory.getLogger(MLDPanel.class);
	
	/**
	 * La toolbar
	 */
	private JComponent toolbar;
	
	/**
	 * Le constructeur de {@link MLDPanel}.
	 * @param analyseSIFrame La fenêtre principale d'AnalyseSI
	 */
	public MLDPanel(AnalyseSIFrame analyseSIFrame) {
		super(analyseSIFrame, "MLD");

		// Initialisation des propriétés


		// Initialisations des actions et de l'interface
		this.initActions();
		this.initGui();
		
	}
	
	/**
	 * Initialisation des différentes actions disponible pour le
	 * {@link DictionaryPanel}.
	 */
	private void initActions() {
		
	}
	
	/**
	 * Initialisation de l'interface du {@link DictionaryPanel}.
	 */
	private void initGui() {
		// Panel
		this.setLayout(new BorderLayout());

		// ToolBar
		toolbar = new JToolBar();
		toolbar.setBackground(UIManager.getColor("JPanel.background"));

		this.add(toolbar, BorderLayout.NORTH);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eucalyptus.analysesi.gui.event.AnalyseSIListener#meriseModelChanged
	 * (org.eucalyptus.analysesi.gui.event.AnalyseSIEvent)
	 */
	@Override
	public void meriseModelChanged(AnalyseSIEvent e) {
		
	}
}
    /*private OldMLDComponent mldComponent;

    private JFileChooser chooser;

    private ActionHandler actionHandler;

    private BasicAction saveGraphic;

    private JPopupMenu popupSaveGraphic;

    private JPanel toolbar;

    public MLDPanel(OldMLDComponent mldComponent)
    {
        super("MLD");
        
        this.mldComponent = mldComponent;
        this.actionHandler = new ActionHandler();

        initAction();
        initToolbar();
        initPopup();

        mldComponent.addMouseListener(new MouseHandler());

        chooser = new JFileChooser();
        chooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
        chooser.setFileHidingEnabled(true);

        AnalyseFilter af;
        FileChooserFilter cf;
        chooser.resetChoosableFileFilters();
        cf = new FileChooserFilter("PNG");
        cf.setExtension("png");
        cf.setDescription("Image PNG");
        chooser.addChoosableFileFilter(cf);
        chooser.setDialogType(JFileChooser.SAVE_DIALOG);

        this.setBorder(BorderFactory.createEmptyBorder(3, 3, 0, 3));

        this.setLayout(new BorderLayout());
        this.add(BorderLayout.CENTER, new JScrollPane(mldComponent));
        this.add(BorderLayout.NORTH, toolbar);
    }

    private void initToolbar()
    {
        toolbar = new JPanel();
        toolbar.setLayout(new FlowLayout(FlowLayout.LEFT));

        toolbar.add(new JButton(saveGraphic) {
            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });
    }

    private void initPopup()
    {
        popupSaveGraphic = new JPopupMenu();
        popupSaveGraphic.add(new JMenuItem(saveGraphic) {
            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });
    }

    private void initAction()
    {
        saveGraphic = new BasicAction("Sauvegarder le graphique",
                "Sauvegarder le graphique dans un fichier PNG", "SAVE_GRAPH",
                ImageLoader.getInstance().getIcon("Save.png"), 0, null);
        saveGraphic.addActionListener(actionHandler);
    }

    public boolean undoEnabled()
    {
        return false;
    }

    public boolean redoEnabled()
    {
        return false;
    }

    public boolean copyEnabled()
    {
        return false;
    }

    public boolean pasteEnabled()
    {
        return false;
    }

    private String chooseFile()
    {
        if (chooser.showDialog(org.eucalyptus.analysesi.Application.analyseFrame, null) == JFileChooser.APPROVE_OPTION) {
            return chooser.getSelectedFile().getAbsolutePath();
        }

        return null;
    }

    private class ActionHandler implements ActionListener
    {
        public void actionPerformed(ActionEvent e)
        {
            String action = e.getActionCommand();
            if (action.equals("SAVE_GRAPH")) {
                String fileName = chooseFile();
                if (fileName == null)
                    return;

                if (!Utilities.getExtension(fileName).equals("png")
                        && !Utilities.getExtension(fileName).equals("PNG"))
                    fileName = fileName + ".png";

                try {
                    File imageFile;
                    FileImageOutputStream outputStream;
                    BufferedImage img;
                    Graphics g;
                    Graphics2D g2d;
                    Rectangle2D r;

                    imageFile = new File(fileName);
                    img = new BufferedImage(
                            (int) (mldComponent.getPreferredSize().getWidth()),
                            (int) (mldComponent.getPreferredSize().getHeight()),
                            BufferedImage.TYPE_INT_RGB);

                    g = img.getGraphics();
                    g2d = (Graphics2D) g;

                    g2d.setColor(new Color(255, 255, 255));
                    r = new Rectangle2D.Double(0, 0, img.getWidth(), img
                            .getHeight());
                    g2d.fill(r);

                    mldComponent.paintComponent(g2d);

                    PNGImageWriter writer = new PNGImageWriter(null);

                    writer.setOutput(outputStream = new FileImageOutputStream(
                            imageFile));
                    writer.write(img);

                    outputStream.close();

                    writer.dispose();

                } catch (IOException err) {
                    GUIUtilities.error("Impossible de sauvegarder le fichier "
                            + fileName);
                }
            }
        }
    }

    private class MouseHandler extends MouseAdapter
    {
        public void mouseReleased(MouseEvent e)
        {
            //if (e.isPopupTrigger()) Ne marche pas avec le JDK d'IBM
            if (e.getButton() == MouseEvent.BUTTON3) {
                popupSaveGraphic.show(e.getComponent(), e.getX(), e.getY());
            }
        }
    }
}*/