/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.save;

import java.io.File;

import org.eucalyptus.analysesi.model.Attribute;
import org.eucalyptus.analysesi.model.MeriseModel;

/**
 * Cette classe crée un fichier au format Eucalyptus d'exemple.
 *
 * @author Loic Dreux
 */
/**
 * 
 * 
 * @author Loic Dreux
 */
public class EucalyptusSaveFileSample {
	/**
	 * La fonction d'entrée
	 * java-class
	 * @param args
	 *            Les arguments
	 */
	public static void main(String... args) {
		try {
			EucalyptusSaveFileSample sample = new EucalyptusSaveFileSample();
			sample.createEucalyptusFile();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Le format de fichier Eucalyptus.
	 */
	private Format eucalyptusFormat;

	/**
	 * Le fichier de test.
	 */
	private File eucalyptusFile;

	/**
	 * Le modèle merise.
	 */
	private MeriseModel meriseModel;

	/**
	 * Le gestionnaire de sauvegarde
	 */
	private SaveManager saveManager;

	/**
	 * Le constructeur {@link EucalyptusFormatTest}
	 */
	public EucalyptusSaveFileSample() {
		saveManager = new DefaultSaveManager();
		meriseModel = new MeriseModel();
		eucalyptusFormat = new HibiscusFormat();
		eucalyptusFile = new File(System.getProperty("user.home")
				+ File.separator + "analysesi."
				+ eucalyptusFormat.getFileExtension());
	}

	/**
	 * Crée le fichier eucalyptus
	 * @throws SaveModelNotSupportedException 
	 * @throws SaveModelException 
	 */
	public void createEucalyptusFile() throws SaveModelException, SaveModelNotSupportedException {
		// Ajout de données dans le modèle
		Attribute attributeNom = new Attribute("Nom");
		Attribute attributePrenom = new Attribute("Prénom");
		Attribute attributeNumeroImmatriculation = new Attribute("Numéro d'immatriculation");
		meriseModel.getDictionary().add(attributeNom);
		meriseModel.getDictionary().add(attributePrenom);
		meriseModel.getDictionary().add(attributeNumeroImmatriculation);
		
		// Sauvegarde du modèle
		saveManager.saveModel(new AnalyseSIModel() {
			@Override
			public MeriseModel getMeriseModel() {
				return meriseModel;
			}
		}, new AnalyseSIFile(eucalyptusFile, eucalyptusFormat));
	}
}
