/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.egt.egraph;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Point;

import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.SwingUtilities;

import org.eucalyptus.analysesi.gui.graph.EntityCell;
import org.eucalyptus.analysesi.gui.graph.EntityCellRenderer;
import org.eucalyptus.analysesi.gui.graph.McdGraphModel;
import org.eucalyptus.analysesi.gui.graph.RelationCell;
import org.eucalyptus.analysesi.gui.graph.RelationCellRenderer;
import org.eucalyptus.analysesi.model.Attribute;
import org.eucalyptus.analysesi.model.Dictionary;
import org.eucalyptus.analysesi.model.Entity;
import org.eucalyptus.analysesi.model.MeriseLink;
import org.eucalyptus.analysesi.model.MCD;
import org.eucalyptus.analysesi.model.Relation;
import org.eucalyptus.egt.EgtUtilities;
import org.eucalyptus.egt.Graph;

/**
 * Cette classe permet d'afficher une frame qui contient
 * un Graph de test.
 *
 * @author Loic Dreux
 */
public class EucalyptusGraphSample {

	/**
	 * Le constructeur {@link EucalyptusGraphSample}.
	 */
	public EucalyptusGraphSample() {
		JFrame frame = new JFrame();
		frame.setSize(new Dimension(500, 500));
		EgtUtilities.centerComponent(frame);
		frame.setLayout(new BorderLayout());
		frame.add(BorderLayout.CENTER, new JScrollPane(buildSampleGraph()));
		frame.setVisible(true);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}
	
	/**
	 * Construit un graph de test
	 */
	private JComponent buildSampleGraph() {
		// Création du dictionnaire
		Dictionary dictionary = new Dictionary();
		Attribute attributeNom = new Attribute("Nom");
		Attribute attributePrenom = new Attribute("Prénom");
		Attribute attributeNumeroImmatriculation = new Attribute("Numéro d'immatriculation");
		dictionary.add(attributeNom);
		dictionary.add(attributePrenom);
		dictionary.add(attributeNumeroImmatriculation);
		
		// Création du MC
		MCD mcd = new MCD(dictionary);
		
		// Ajout de l'entité Personne
		Entity entityPersonne = new Entity("Personne");
		entityPersonne.addAttribute(attributeNom);
		entityPersonne.addAttribute(attributePrenom);
		mcd.addEntity(entityPersonne);
		
		// Ajout de l'entité Voiture
		Entity entityVoiture = new Entity("Voiture");
		entityVoiture.addAttribute(attributeNumeroImmatriculation);
		mcd.addEntity(entityVoiture);
		
		// Ajout d'une association
		Relation relationPossede = new Relation("possede");
		mcd.addRelation(relationPossede);
		
		// Ajout des liens
		MeriseLink meriseLink = new MeriseLink();
		entityVoiture.addLink(meriseLink);
		relationPossede.addLink(meriseLink);
		
		McdGraphModel mcdGraphModel = new McdGraphModel(mcd);
		mcdGraphModel.getEntityCell(entityPersonne).setPosition(new Point(50,50));
		mcdGraphModel.getEntityCell(entityVoiture).setPosition(new Point(150,150));
		mcdGraphModel.getRelationCell(relationPossede).setPosition(new Point(50,150));
		Graph graph = new Graph(mcdGraphModel);
		graph.setCellRenderer(EntityCell.class, new EntityCellRenderer());
		graph.setCellRenderer(RelationCell.class, new RelationCellRenderer());
		return graph;
	}
	
	/**
	 * La méthode d'entrée du test
	 * @param args les arguments
	 */
	public static void main(String[] args) {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				new EucalyptusGraphSample();
			}
		});
	}

}
