/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.db;

/**
 * Les paramètres de connection à une base de données.
 *
 * @author Loic Dreux
 */
public class DbConnectionParameters {
	/**
	 * L'url de la connection.
	 */
	private String url;
	
	/**
	 * L'utilisateur.
	 */
	private String user;
	
	/**
	 * Le mot de passe.
	 */
	private String password;
	
	/**
	 * Le driver JDBC.
	 */
	private String driver;
	
	/**
	 * Le constructeur de la classe {@link DbConnectionParameters}.
	 * @param url
	 * @param user
	 * @param password
	 * @param driver
	 */
	public DbConnectionParameters(String url, String user, String password, String driver) {
		this.url = url;
		this.user = user;
		this.password = password;
		this.driver = driver;
	}

	/**
	 * Retourne l'url.
	 * @return the url
	 */
	public String getUrl() {
		return url;
	}

	/**
	 * Modifie l'url.
	 * @param url the url to set
	 */
	public void setUrl(String url) {
		this.url = url;
	}

	/**
	 * Retourne l'utilisateur.
	 * @return the user
	 */
	public String getUser() {
		return user;
	}

	/**
	 * Modifie l'utilisateur.
	 * @param user the user to set
	 */
	public void setUser(String user) {
		this.user = user;
	}

	/**
	 * Retourne le mot de passe.
	 * @return the password
	 */
	public String getPassword() {
		return password;
	}

	/**
	 * Modifie le mot de passe.
	 * @param password the password to set
	 */
	public void setPassword(String password) {
		this.password = password;
	}

	/**
	 * Retourne le driver Jdbc.
	 * @return the driver
	 */
	public String getDriver() {
		return driver;
	}

	/**
	 * Modifie le driver Jdbc.
	 * @param driver the driver to set
	 */
	public void setDriver(String driver) {
		this.driver = driver;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object o) {
		if (! (o instanceof DbConnectionParameters))
			return false;
		
		DbConnectionParameters connection = (DbConnectionParameters)o;
		return this.driver.equals(connection.driver) &&
			this.password.equals(connection.password) &&
			this.user.equals(connection.user) &&
			this.url.equals(connection.url);
	}
}
