/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.db;

import java.util.List;

/**
 * Le gestionnaire de base de données.
 *
 * @author Loic Dreux
 */
public interface DbManager {
	/**
	 * Ajoute un nouveau driver Jdbc.
	 * @param driver Le driver
	 * @param urlStart Le début de l'url
	 * @param sqlTestQuery La requête de test
	 */
	public void addJdbcDriver(Class<?> driver, String urlStart, String sqlTestQuery);
	
	/**
	 * Retourne la liste des drivers JDBC pris en charge.
	 * @return la liste des drivers JDBC pris en charge
	 */
	public List<Class<?>> getJdbcDrivers();
	
	/**
	 * Retourne le début de l'url selon le driver.
	 * @param driver Le driver
	 * @return le début de l'url selon le driver
	 */
	public String getUrlStart(Class<?> driver);
	
	/**
	 * Retourne la requête sql de test.
	 * Cette requête doit retourner 1.
	 * @param driver Le driver
	 * @return la requête sql de test qui doit retourné 1
	 */
	public String getSqlTestQuery(Class<?> driver);
	
	/**
	 * Test une connection vers une base de données.
	 * @param connectionParameters les paramètres de connection
	 * @return true si la connection a réussi, false dans le cas contraire
	 */
	public boolean testConnection(DbConnectionParameters connectionParameters);
	
	/**
	 * Retourne la liste des connections paramètrées.
	 * @return la liste des connections paramètrées
	 */
	public List<DbConnectionParameters> getConfiguredConnections();
	
	/**
	 * Enregistre la liste des connections paramètrées.
	 * @param configuredConnections la liste des connections paramètrées
	 */
	public void saveConfiguredConnections(List<DbConnectionParameters> configuredConnections);
	
	/**
	 * Retourne le driver Jdbc correspond aux paramètres.
	 * @param connection les paramètres
	 * @return le driver Jdbc correspondant aux paramètres
	 */
	public Class<?> getJdbcDriver(DbConnectionParameters connection);
}
