/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.net.URL;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JEditorPane;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;

import org.eucalyptus.egt.EgtUtilities;
import org.eucalyptus.egt.action.EucalyptusAction;
import org.eucalyptus.egt.factory.PanelFactory;
import org.eucalyptus.egt.loader.ImageLoader;
import org.eucalyptus.egt.loader.ResourceLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * La fenêtre d'A Propos de l'application AnalyseSI.
 * 
 * @author Loic Dreux
 */
public class AboutWindow extends JDialog implements ActionListener {
	// Le logger
	private Logger logger = LoggerFactory.getLogger(AboutWindow.class);
	
	/**
	 * L'action de fermeture de la fenêtre.
	 */
	private EucalyptusAction close;

	/**
	 * Le constructeur de la fenêtre A Propos
	 * 
	 * @param parent
	 *            La frame Parent
	 */
	public AboutWindow(AnalyseSIFrame analyseSIFrame) {
		super(analyseSIFrame, analyseSIFrame.getName());

		// Initialise les actions
		initActions();

		// Le panneau
		JPanel p = new JPanel(new BorderLayout());

		// L'image du logo
		JLabel img = new JLabel(ImageLoader.getInstance().getIcon("Logo.png")); //$NON-NLS-1$
		img.setBorder(BorderFactory.createEtchedBorder());

		JPanel pImg = new JPanel(new BorderLayout());
		pImg.add(img, BorderLayout.CENTER);
		pImg.setBorder(BorderFactory.createEmptyBorder(8, 8, 8, 8));

		JTabbedPane pane = new JTabbedPane();
		pane.setBorder(BorderFactory.createEmptyBorder(8, 8, 8, 8));
		pane.add(Messages.getString("AboutWindow.about"), pImg); //$NON-NLS-1$
		pane.add(Messages.getString("AboutWindow.author"), buildAuthorPane()); //$NON-NLS-1$
		pane.add(Messages.getString("AboutWindow.whatsnew"), buildWhatsnewPane()); //$NON-NLS-1$
		pane.add(Messages.getString("AboutWindow.license"), buildLicensePane()); //$NON-NLS-1$

		p.add(BorderLayout.CENTER, pane);
		p.add(BorderLayout.SOUTH, PanelFactory.buildBottomPanel(new JButton(close)));

		// On ajoute le tout, on redimensionne, on centre et on affiche
		this.getContentPane().add(p);
		this.setSize(new Dimension(540, 550));
		this.setResizable(false);
		EgtUtilities.centerComponent(this);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand().equals(Actions.CLOSE.name())) {
			this.setVisible(false);
		}
	}

	/**
	 * Fabrique la panneau Autheur.
	 * 
	 * @return le panneau autheur
	 */
	private JPanel buildAuthorPane() {
		JPanel panel = new JPanel(new BorderLayout());
		URL url = ResourceLoader.getInstance().getTextResource("author.txt"); //$NON-NLS-1$

		try {

			JEditorPane editor = new JEditorPane(url);
			editor.setEditable(false);
			panel.setBorder(BorderFactory.createEmptyBorder(8, 8, 8, 8));

			panel.add(new JScrollPane(editor), BorderLayout.CENTER);
		} catch (IOException e) {
			logger.error(e.getLocalizedMessage(), e);
		}

		return panel;
	}

	/**
	 * Fabrique le panneau license.
	 * 
	 * @return le panneau license
	 */
	private JPanel buildLicensePane() {
		JPanel panel = new JPanel(new BorderLayout());
		URL url = ResourceLoader.getInstance().getHtmlResource("GPL.html"); //$NON-NLS-1$
		try {
			JEditorPane editor = new JEditorPane(url);
			editor.setEditable(false);

			panel.setBorder(BorderFactory.createEmptyBorder(8, 8, 8, 8));
			panel.add(new JScrollPane(editor), BorderLayout.CENTER);
		} catch (IOException e) {
			logger.error(e.getLocalizedMessage(), e);
		}

		return panel;
	}

	/**
	 * Fabrique le panneau Quoi de neuf.
	 * 
	 * @return le panneau Quoi de neuf
	 */
	private JPanel buildWhatsnewPane() {
		JPanel panel = new JPanel(new BorderLayout());
		URL url = ResourceLoader.getInstance().getTextResource("whatsnew.txt"); //$NON-NLS-1$

		try {

			JEditorPane editor = new JEditorPane(url);
			editor.setEditable(false);
			panel.setBorder(BorderFactory.createEmptyBorder(8, 8, 8, 8));

			panel.add(new JScrollPane(editor), BorderLayout.CENTER);
		} catch (IOException e) {
			logger.error(e.getLocalizedMessage(), e);
		}

		return panel;
	}

	/**
	 * Initialise les actions.
	 */
	private void initActions() {
		close = new EucalyptusAction(Messages.getString("AboutWindow.close"), Messages.getString("AboutWindow.closeLong"), Actions.CLOSE.name(), null, 0, null); //$NON-NLS-1$ //$NON-NLS-2$
		close.addActionListener(this);
	}

	/**
	 * La liste des actions locales.
	 * 
	 * @author Loic Dreux
	 */
	private enum Actions {
		// Ferme la fenêtre
		CLOSE
	}
}