/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Container;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JPanel;

import org.eucalyptus.egt.factory.PanelFactory;

/**
 * Une boite de dialogue standard AnalyseSI
 * 
 * @author Loic Dreux
 */
public abstract class AnalyseSIDialog extends JDialog {
	/**
	 * La fenêtre principale d'AnalyseSI
	 */
	private AnalyseSIFrame analyseSIFrame;

	/**
	 * La description de la boite de dialogue.
	 */
	private String description;

	/**
	 * L'icone de la boite de dialogue.
	 */
	private ImageIcon icon;

	/**
	 * Le panneau qui contient les boutons.
	 */
	private JPanel bottomWhitePanel;

	/**
	 * Constructeur {@link AnalyseSIDialog}.
	 * 
	 * @param analyseSIFrame
	 *            la fenêtre principale d'AnalyseSI
	 * @param title
	 *            le titre de la boite de dialogue
	 */
	public AnalyseSIDialog(AnalyseSIFrame analyseSIFrame, String title) {
		this(analyseSIFrame, title, "");
	}

	/**
	 * Constructeur {@link AnalyseSIDialog}.
	 * 
	 * @param analyseSIFrame
	 *            la fenêtre principale d'AnalyseSI
	 * @param title
	 *            le titre de la boite de dialogue
	 * @param description
	 *            la description de la boite de dialogue
	 */
	public AnalyseSIDialog(AnalyseSIFrame analyseSIFrame, String title, String description) {
		this(analyseSIFrame, title, "", null);
	}

	/**
	 * Constructeur {@link AnalyseSIDialog}.
	 * 
	 * @param analyseSIFrame
	 *            la fenêtre principale d'AnalyseSI
	 * @param title
	 *            le titre de la boite de dialogue
	 * @param description
	 *            la description de la boite de dialogue
	 * @param icon
	 *            L'image de la boite de dialogue
	 */
	public AnalyseSIDialog(AnalyseSIFrame analyseSIFrame, String title, String description, ImageIcon icon) {
		super(analyseSIFrame, analyseSIFrame.getName());

		// Affectation des propriétés
		this.analyseSIFrame = analyseSIFrame;
		this.description = description;
		this.icon = icon;

		// Les containers
		Container c = this.getContentPane();
		c.setLayout(new BorderLayout());

		// On initialise les panneaux
		bottomWhitePanel = PanelFactory.buildBottomWhitePanel();

		// On ajoute le panneau
		c.add(BorderLayout.NORTH, PanelFactory.buildTitlePanel(title, description, icon));
		c.add(BorderLayout.SOUTH, bottomWhitePanel);
	}

	/**
	 * Ajoute un bouton dans la partie bas de la boite de dialogue.
	 * 
	 * @param button
	 *            Le bouton à ajouter
	 */
	public void addBottomButton(JButton ... buttons) {
		for (JButton button: buttons) {
			bottomWhitePanel.add(button);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.Container#add(java.awt.Component)
	 */
	@Override
	public Component add(Component component) {
		Container c = this.getContentPane();
		c.add(BorderLayout.CENTER, component);
		return component;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.JDialog#remove(java.awt.Component)
	 */
	@Override
	public void remove(Component component) {
		Container c = this.getContentPane();
		c.remove(component);
	}

	/**
	 * Retourne la fenêtre principale d'AnalyseSI.
	 * 
	 * @return the analyseSIFrame
	 */
	public AnalyseSIFrame getAnalyseSIFrame() {
		return analyseSIFrame;
	}

	/**
	 * @return the description
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * @return the icon
	 */
	public ImageIcon getIcon() {
		return icon;
	}
}
