/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JMenuBar;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;
import javax.swing.JToolBar;

import org.eucalyptus.analysesi.AnalyseSIApplication;
import org.eucalyptus.analysesi.gui.action.ActionsCollection;
import org.eucalyptus.analysesi.gui.action.CommandKey;
import org.eucalyptus.analysesi.gui.dictionary.DictionaryPanel;
import org.eucalyptus.analysesi.gui.event.AnalyseSIEvent;
import org.eucalyptus.analysesi.gui.event.AnalyseSIListener;
import org.eucalyptus.analysesi.gui.factory.MenuFactory;
import org.eucalyptus.analysesi.gui.factory.ToolbarFactory;
import org.eucalyptus.analysesi.gui.help.HelpPanel;
import org.eucalyptus.analysesi.gui.mcd.MCDPanel;
import org.eucalyptus.analysesi.gui.mld.MLDPanel;
import org.eucalyptus.analysesi.gui.plugin.PluginsDialog;
import org.eucalyptus.analysesi.gui.reverse.ReverseDialog;
import org.eucalyptus.analysesi.model.MeriseModel;
import org.eucalyptus.analysesi.save.AnalyseSIFile;
import org.eucalyptus.analysesi.save.AnalyseSIModel;
import org.eucalyptus.egt.EgtUtilities;
import org.eucalyptus.egt.JEFrame;
import org.eucalyptus.egt.JESplashScreen;
import org.eucalyptus.egt.loader.ImageLoader;
import org.jdesktop.swingx.JXStatusBar;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * La fenêtre principale d'AnalyseSI.
 */
public class AnalyseSIFrame extends JEFrame<AnalyseSIApplication> implements
		AnalyseSIModel {
	// Le logger
	@SuppressWarnings("unused")//$NON-NLS-1$
	private static final Logger logger = LoggerFactory
			.getLogger(AnalyseSIFrame.class);

	/*
	 * ============================================= L'application
	 */

	/**
	 * L'application.
	 */
	private AnalyseSIApplication analyseSIApplication;

	/*
	 * ============================================= Les boites de dialogues
	 */
	
	/**
	 * Fenetre A Propos.
	 */
	private AboutWindow aboutWindow;

	/**
	 * La boite de Reverse Engineering
	 */
	private ReverseDialog reverseDialog;

	/**
	 * La boite de gestion des plugins
	 */
	private PluginsDialog pluginsDialog;

	/*
	 * AnalyseSIModel ============================================= Les Panels
	 */

	/**
	 * Le panel du dictionnaire
	 */
	private DictionaryPanel dictionaryPanel;

	/**
	 * La panel d'aide.
	 */
	private AnalyseSIPanel helpPanel;
	
	/**
	 * Le panel qui contient le MCD.
	 */
	private MCDPanel mcdPanel;

	/**
	 * Le panel qui contient le MLD.
	 */
	private MLDPanel mldPanel;
	
	/**
	 * Le panel courant.
	 */
	private AnalyseSIPanel panelCurrent;

	/*toolbar.add(new JButton(showAddAttributePanelAction));
		// toolbar.add(new JButton(actionManager.getAction("action-movedown")));
		// toolbar.add(new
		
	 * ============================================= Les autres composants
	 */

	/**
	 * La barre AnalyseSI.
	 */
	private AnalyseSIBar analyseBar;

	/**
	 * Le menu d'AnalyseSI.
	 */
	private JMenuBar menu;

	/**
	 * Contient la barre de status
	 */
	private JXStatusBar statusbar;

	/**
	 * La barre d'outil.
	 */
	private JToolBar toolbar;

	/*
	 * ============================================= Le modèle
	 */

	/**
	 * Le modèle Merise.
	 */
	private MeriseModel meriseModel;

	/*
	 * ============================================= La gestion des actions
	 */

	/**
	 * La liste des listeners pour AnalyseSI.
	 */
	private List<AnalyseSIListener> analyseSIListeners;
	
	/**
	 * Toutes les Actions globales
	 */
	private ActionsCollection actionsCollection;

	/*
	 * ============================================= Les Managers
	 */

	/**
	 * Le gestionnaire de propriétés
	 */
	private PropertiesManager propertiesManager;

	/**
	 * Le Constructeur {@link AnalyseSIFrame}.
	 * 
	 * @param analyseSIApplication
	 *            L'applicationclass
	 * @param splashScreen
	 *            le splashScreen
	 * @param debug
	 *            true pour activer le mode debug, false sinon
	 */
	public AnalyseSIFrame(final AnalyseSIApplication analyseSIApplication,
			JESplashScreen splashScreen) {
		super(analyseSIApplication);

		// Affectation des propriétés
		this.analyseSIApplication = analyseSIApplication;

		// Initilisation du modèle
		this.meriseModel = new MeriseModel();

		// Changement d'icone
		this.setIconImage(ImageLoader.getInstance()
				.getIcon("analysesi.png").getImage()); //$NON-NLS-1$
		splashScreen.setProgress(10);

		// Gestion des évènements/actions
		initActionsAndListeners();
		splashScreen.setProgress(20);

		// Constuction des Menus
		menu = MenuFactory.buildMenu(actionsCollection);
		toolbar = ToolbarFactory.buildToolbar(actionsCollection);
		splashScreen.setProgress(30);

		// Constuction des Panels
		this.helpPanel = new HelpPanel(this);
		this.dictionaryPanel = new DictionaryPanel(this);
		this.addAnalyseSIListener(dictionaryPanel);
		this.mcdPanel = new MCDPanel(this);
		this.addAnalyseSIListener(mcdPanel);
		this.mldPanel = new MLDPanel(this);
		this.addAnalyseSIListener(mldPanel);

		// Initialisation de la statubar
		splashScreen.setProgress(40);
		this.statusbar = new JXStatusBar();

		// Initialisation des dialogues
		this.aboutWindow = new AboutWindow(this);
		this.reverseDialog = new ReverseDialog(this);
		this.pluginsDialog = new PluginsDialog(this);

		// Container
		Container c = this.getContentPane();
		c.setLayout(new BorderLayout());

		// Nord
		c.add(BorderLayout.NORTH, new JPanel(new BorderLayout()) {
			{
				this.add(BorderLayout.NORTH, menu);
				this.add(BorderLayout.SOUTH, toolbar);
			}
		});

		// Centre
		JTabbedPane tabbedPane = new JTabbedPane();
		tabbedPane.addTab(Messages.getString("AnalyseSIFrame.help"),
				ImageLoader.getInstance().getIcon("About.png"), helpPanel);
		tabbedPane
				.addTab(Messages.getString("AnalyseSIFrame.dictionary"),
						ImageLoader.getInstance().getIcon("Table.png"),
						dictionaryPanel);
		tabbedPane.addTab("MCD",ImageLoader.getInstance().getIcon("Mcd.png"), mcdPanel);
		tabbedPane.addTab("MLD",ImageLoader.getInstance().getIcon("Mld.png"), mldPanel);
		c.add(BorderLayout.CENTER, tabbedPane);

		// Sud
		c.add(BorderLayout.SOUTH, statusbar);
		splashScreen.setProgress(60);

		// Redimensionement et mise au centre
		this.setSize(640, 480);
		EgtUtilities.centerComponent(this);
		splashScreen.setProgress(70);

		// Gestion des sauvegardes
		splashScreen.setProgress(80);

		// Chargement des propriétés
		propertiesManager = new PropertiesManager(this);
		propertiesManager.loadProperties();

		// Mise à jour du titre
		this.updateTitle();
	}
	
	/**
	 * Ajoute un listener.
	 * @param analyseSIListener le listener à ajouter
	 */
	public void addAnalyseSIListener(AnalyseSIListener analyseSIListener) {
		analyseSIListeners.add(analyseSIListener);
	}
	
	/**
	 * Supprime un listener.
	 * @param analyseSIListener le listener à supprimer
	 */
	public void removeAnalyseSIListener(AnalyseSIListener analyseSIListener) {
		analyseSIListeners.remove(analyseSIListener);
	}

	/**
	 * Ferme proprement en sauvegardant les paramètres.
	 */
	public void exit() {
		propertiesManager.saveProperties();
		System.exit(0);
	}

	/**
	 * @return the aboutWindow
	 */
	public AboutWindow getAboutWindow() {
		return aboutWindow;
	}

	/**
	 * Retourne la bar de titre.
	 */
	public AnalyseSIBar getAnalyseBar() {
		return analyseBar;
	}

	/**
	 * Retourne l'application
	 * 
	 * @return the application
	 */
	public AnalyseSIApplication getApplication() {
		return analyseSIApplication;
	}

	/**
	 * Retourne le panel courant.
	 */
	public AnalyseSIPanel getCurrentPanel() {
		return panelCurrent;
	}

	/**
	 * Retourne le modèle merise.
	 * 
	 * @return le modèle merise
	 */
	public MeriseModel getMeriseModel() {
		return meriseModel;
	}

	/**
	 * Retourne la boite de dialogue de gestion des plugins.
	 * 
	 * @return la boite de dialogue de gestion des plugins
	 */
	public PluginsDialog getPluginsDialog() {
		return pluginsDialog;
	}

	/**
	 * Retourne la boite de dialogue de Reverse Engineering
	 * 
	 * @return the reverseDialog
	 */
	public ReverseDialog getReverseDialog() {
		return this.reverseDialog;
	}

	/**
	 * Initialisation des évènements/actions
	 */
	private void initActionsAndListeners() {
		// On initialises les actions et Listeners
		this.actionsCollection = new ActionsCollection(this);
		this.addWindowListener(new WindowHandler());
		this.analyseSIListeners = new ArrayList<AnalyseSIListener>();

		// On désactive certaines actions
		for (CommandKey commandKey : new CommandKey[] { CommandKey.REDO,
				CommandKey.UNDO, CommandKey.CUT, CommandKey.COPY,
				CommandKey.PASTE }) {
			actionsCollection.getAction(commandKey).setEnabled(false);
		}
	}

	/**
	 * Modifie le modèle AnalyseSI
	 * 
	 * @param analyseSIModel
	 *            Le nouveau model
	 */
	public void setAnalyseSIModel(AnalyseSIModel analyseSIModel) {
		this.meriseModel = analyseSIModel.getMeriseModel();
		
		AnalyseSIEvent event = new AnalyseSIEvent(meriseModel);
		for (AnalyseSIListener listener: analyseSIListeners) {
			listener.meriseModelChanged(event);
		}
	}

	/**
	 * Met à jour le titre de la fenêtre à partir des informations de l'état de
	 * la sauvegarde.
	 */
	private void updateTitle() {
		// Récupération du fichier
		AnalyseSIFile analyseSIFile = getApplication().getSaveManager()
				.getCurrentAnalyseSIFile();
		String filename;
		String isModified;

		// Récupération du nom de fichier
		if (analyseSIFile == null) {
			filename = "Nouveau document";
		} else {
			filename = analyseSIFile.getFile().getName();
		}

		// On vérifie si il y a eu modification
		isModified = getApplication().getSaveManager().isModified() ? " (*)"
				: "";

		this.setTitle(analyseSIApplication.getName() + " - " + filename
				+ isModified);
	}

	/**
	 * Le handle de la fenêtre.
	 * 
	 * @author Loic Dreux PluginManager
	 */
	private class WindowHandler extends WindowAdapter {
		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * java.awt.event.WindowAdapter#windowClosing(java.awt.event.WindowEvent
		 * )
		 */
		@Override
		public void windowClosing(WindowEvent evt) {
			AnalyseSIFrame.this.exit();
		}
	}
}