/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui;

import javax.swing.JPanel;


/**
 * La classe panel Module est dérivé {@link JPanel} et peut implémenter les
 * interfaces {@link UndoInterface} et {@link ClipboardInterface}.
 * 
 * @author Loic Dreux
 */
public abstract class AnalyseSIPanel extends JPanel {
	private AnalyseSIFrame analyseSIFrame;
	private boolean undoEnabled;
	private boolean redoEnabled;
	private boolean copyEnabled;
	private boolean pasteEnabled;
	private String id;

	/**
	 * Le constructeur d'une {@link AnalyseSIPanel}.
	 * 
	 * @param id
	 *            l'identifiant du panel
	 */
	public AnalyseSIPanel(AnalyseSIFrame analyseSIFrame, String id) {
		this.analyseSIFrame = analyseSIFrame;
		this.id = id;
	}

	/**
	 * Retourne la fenêtre principale AnalyseSI
	 * 
	 * @return the analyseSIFrame
	 */
	public AnalyseSIFrame getAnalyseSIFrame() {
		return analyseSIFrame;
	}

	/**
	 * Retourne l'identifiant du panel.
	 * 
	 * @return l'identifiant du panel
	 */
	public String getId() {
		return id;
	}

	/**
	 * Indique si le bouton Undo doit être actif.
	 * 
	 * @return true si le bouton Undo doit être actif, false sinon
	 */
	public boolean getUndoEnabled() {
		return undoEnabled;
	}

	/**
	 * Indique si le bouton Redo doit être actif.
	 * 
	 * @return true si le bouton Redo doit être actif, false sinon
	 */
	public boolean getRedoEnabled() {
		return redoEnabled;
	}

	/**
	 * Indique si le bouton Copy doit etre actif.
	 * 
	 * @return true si le bouton Copy doit être actif, false sinon
	 */
	public boolean getCopyEnabled() {
		return copyEnabled;
	}

	/**
	 * Indique si le bouton Paste doit etre actif.
	 * 
	 * @return true si le bouton paste doit être actif, false sinon
	 */
	public boolean getPasteEnabled() {
		return pasteEnabled;
	}

	/**
	 * Active le bouton Undo dans l'interface.
	 * 
	 * @param undoEnabled
	 *            true pour activer le mode Undo, false le désactiver
	 */
	public void setUndoEnabled(boolean undoEnabled) {
		this.undoEnabled = undoEnabled;
	}

	/**
	 * Active le bouton Redo dans l'interface.
	 * 
	 * @param undoEnabled
	 *            true pour activer le mode Redo, false le désactiver
	 */
	public void setRedoEnabled(boolean redoEnabled) {
		this.redoEnabled = redoEnabled;
	}

	/**
	 * Active le bouton Copy dans l'interface.
	 * 
	 * @param undoEnabled
	 *            true pour activer le mode Copy, false le désactiver
	 */
	public void setCopyEnabled(boolean copyEnabled) {
		this.copyEnabled = copyEnabled;
	}

	/**
	 * Active le bouton Paste dans l'interface.
	 * 
	 * @param undoEnabled
	 *            true pour activer le mode Paste, false le désactiver
	 */
	public void setPasteEnabled(boolean pasteEnabled) {
		this.pasteEnabled = pasteEnabled;
	}
}