/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JEditorPane;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JViewport;
import javax.swing.JWindow;

import org.eucalyptus.egt.EgtUtilities;
import org.eucalyptus.egt.action.EucalyptusAction;
import org.eucalyptus.egt.factory.PanelFactory;

/**
 * Cette Fenetre affiche un document Html, elle peut servir pour afficher de
 * l'aide par exemple.
 */
public class HtmlWindow extends JWindow implements ActionListener {
	/**
	 * L'action de fermeture de la fenêtre.
	 */
	private EucalyptusAction close;

	/**
	 * L'éditeur HTML.
	 */
	private JEditorPane editor;

	/**
	 * Créer une nouvelle fenêtre d'information.
	 * 
	 * @param parent
	 *            la frame parent
	 * @param text
	 *            Le text html
	 * @param width
	 *            la largeur
	 * @param height
	 *            la hauteur
	 * @param visible
	 *            true pour afficher la fenêtre, false sinon
	 * @param closeAfter2sec
	 *            true pour n'afficher la fenêtre que 2 secondes
	 */
	public HtmlWindow(JFrame parent, String text, int width, int height, boolean visible, boolean closeAfter2sec) {
		super(parent);

		// Création de l'éditeur
		editor = new JEditorPane("text/html", text) { //$NON-NLS-1$
			public void paintComponent(Graphics g) {
				Graphics2D g2d = (Graphics2D) g;
				g2d.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
				super.paintComponent(g2d);
			}
		};
		editor.setEditable(false);

		// Initialisation des actions
		initActions();

		// Création du container
		Container c = this.getContentPane();
		c.setLayout(new BorderLayout());
		JPanel p = new JPanel();
		p.setLayout(new BorderLayout());
		p.setBorder(BorderFactory.createEmptyBorder(2, 2, 2, 2));

		// On ajoute l'éditeur
		p.add(BorderLayout.CENTER, new JPanel(new BorderLayout()) {
			{
				this.setBorder(BorderFactory.createEmptyBorder(8, 8, 8, 8));
				this.add(BorderLayout.CENTER, new JScrollPane(editor) {
					{
						JViewport vp = this.getViewport();
						vp.add(editor);
					}
				});
			}
		});
		p.add(BorderLayout.SOUTH, PanelFactory.buildBottomWhitePanel(new JButton(close)));
		c.add(p);

		// On redimensionne
		this.setSize(width, height);

		// On centre la fenêtre
		EgtUtilities.centerComponent(this);

		// On l'affiche
		this.setVisible(visible);

		// On la ferme si nécessaire
		if (closeAfter2sec) {
			this.closeAfter2sec();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand().equals(Actions.CLOSE.name())) {
			this.setVisible(false);
		}
	}

	/**
	 * Masque la fenêtre au bout de 2 secondes.
	 */
	public void closeAfter2sec() {
		Thread t = new Thread(new Runnable() {
			public void run() {
				try {
					Thread.sleep(3000);
					setVisible(false);
				} catch (InterruptedException e) {
					setVisible(false);
				}
			}
		});
		t.start();
	}

	/**
	 * Initialisation des actions
	 */
	private void initActions() {
		close = new EucalyptusAction(
				Messages.getString("HtmlWindow.Close"), Messages.getString("HtmlWindow.CloseLong"), Actions.CLOSE.name(), null, 0, null); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
		close.addActionListener(this);
	}

	/**
	 * La liste des actions locales.
	 * 
	 * @author Loic Dreux
	 */
	private enum Actions {
		// Fermeture de la fenêtre
		CLOSE,
	}
}