/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Le gestionnaire de propriété d'AnalyseSI.
 * 
 * @author Loic Dreux
 */
public class PropertiesManager {
	// Le logger
	public static final Logger logger = LoggerFactory.getLogger(PropertiesManager.class);

	/**
	 * Les propriétés
	 */
	private Properties props;

	/**
	 * La fenêtre principale d'AnalyseSI
	 */
	private AnalyseSIFrame analyseSIFrame;

	/**
	 * Le fichier qui contient les propriétés
	 */
	private File propertiesFile;

	/**
	 * Le constructeur du gestionnaire de propriétés.
	 * 
	 * @param analyseSIFrame
	 *            la fenêtre principale d'AnalyseSI
	 */
	public PropertiesManager(AnalyseSIFrame analyseSIFrame) {
		this.analyseSIFrame = analyseSIFrame;
		this.props = new Properties();
		this.propertiesFile = new File(analyseSIFrame.getApplication().getSettingsDirectory() + File.separator + "analysesi.properties");
	}

	/**
	 * Sauvegarde les propriétés dans un fichier.
	 */
	public void saveProperties() {
		try {
			FileOutputStream fos = new FileOutputStream(propertiesFile);

			props.setProperty("X", "" + analyseSIFrame.getX());
			props.setProperty("Y", "" + analyseSIFrame.getY());
			props.setProperty("width", "" + analyseSIFrame.getWidth());
			props.setProperty("height", "" + analyseSIFrame.getHeight());

			props.store(fos, "properties");
		} catch (IOException e) {
			logger.error(e.getLocalizedMessage(), e);
		}
	}

	/**
	 * Récupère les propriétés depuis un fichier.
	 */
	public void loadProperties() {
		try {
			FileInputStream fis = new FileInputStream(propertiesFile);
			props.load(fis);
		} catch (IOException e) {
			initProperties();
		}

		if (!validProperties())
			initProperties();

		analyseSIFrame.setBounds(new Integer(props.getProperty("X")).intValue(), new Integer(props.getProperty("Y"))
				.intValue(), new Integer(props.getProperty("width")).intValue(), new Integer(props
				.getProperty("height")).intValue());
	}

	/**
	 * Vérifie que toutes les propriétés sont correctes.
	 */
	public boolean validProperties() {
		return props.getProperty("X") != null && props.getProperty("Y") != null && props.getProperty("height") != null
				&& props.getProperty("width") != null && props.getProperty("tree") != null;
	}

	/**
	 * Initialise les propriétés par défaut.
	 */
	public void initProperties() {
		File dir = analyseSIFrame.getApplication().getSettingsDirectory();

		if (!dir.exists())
			dir.mkdir();

		try {
			FileOutputStream fos = new FileOutputStream(propertiesFile);

			props.setProperty("X", "0");
			props.setProperty("Y", "0");
			props.setProperty("width", "640");
			props.setProperty("height", "480");

			props.store(fos, "properties");
		} catch (IOException e) {
			logger.error(e.getLocalizedMessage(), e);
		}
	}
}
