/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.action;

import java.util.Hashtable;

import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.eucalyptus.egt.action.EucalyptusAction;

/**
 * Cette classe regroupe toutes les actions globales d'AnalyseSI.
 */
public class ActionsCollection {
	/**
	 * La collection d'actions.
	 */
	private Hashtable<CommandKey, EucalyptusAction> actionsCollection;

	/**
	 * Créer les différentes actions.
	 */
	public ActionsCollection(AnalyseSIFrame analyseSIFrame) {
		// On instance la collection d'actions
		actionsCollection = new Hashtable<CommandKey, EucalyptusAction>();

		// On créer les actions
		actionsCollection.put(CommandKey.NEW, new NewAction(analyseSIFrame));
		actionsCollection.put(CommandKey.OPEN, new OpenAction(analyseSIFrame));
		actionsCollection.put(CommandKey.SAVE, new SaveAction(analyseSIFrame));
		actionsCollection.put(CommandKey.SAVEAS, new SaveAsAction(analyseSIFrame));
		actionsCollection.put(CommandKey.QUIT, new QuitAction(analyseSIFrame));
		actionsCollection.put(CommandKey.UNDO, new UndoAction(analyseSIFrame));
		actionsCollection.put(CommandKey.REDO, new RedoAction(analyseSIFrame));
		actionsCollection.put(CommandKey.CUT, new CutAction(analyseSIFrame));
		actionsCollection.put(CommandKey.COPY, new CopyAction(analyseSIFrame));
		actionsCollection.put(CommandKey.PASTE, new PasteAction(analyseSIFrame));
		actionsCollection.put(CommandKey.ABOUT, new AboutAction(analyseSIFrame));
		actionsCollection.put(CommandKey.OPEN_REVERSE_DIALOG, new OpenReverseDialog(analyseSIFrame));
		actionsCollection.put(CommandKey.OPEN_PLUGINS_DIALOG, new OpenPluginsDialog(analyseSIFrame));
	}

	/**
	 * Retourne une EucalyptusAction utilisable dans un composant graphique.
	 * 
	 * @param commandKey La commandKey de l'action
	 */
	public EucalyptusAction getAction(CommandKey commandKey) {
		return actionsCollection.get(commandKey);
	}
}