/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
/**
 * 
 */
package org.eucalyptus.analysesi.gui.action;

import javax.swing.ImageIcon;
import javax.swing.KeyStroke;

import org.eucalyptus.analysesi.AnalyseSIApplication;
import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.eucalyptus.egt.action.EucalyptusAction;

/**
 *
 * @author Loic Dreux
 */
public abstract class AnalyseSIAction extends EucalyptusAction {
	/**
	 * La fenêtre principale AnalyseSI.
	 */
	private AnalyseSIFrame analyseSIFrame;
	
	/**
	 * L'application d'AnalyseSI. 
	 */
	private AnalyseSIApplication analyseSIApplication;
	
	/**
	 * Le constructeur d'une Action.
	 * @param analyseSIFrame la fenêtre principale d'AnalyseSI
	 * @param name Le nom de l'action
	 * @param longDescription La description longue
	 * @param actionCommand La commande associée à l'action
	 */
	public AnalyseSIAction(AnalyseSIFrame analyseSIFrame, String name, String longDescription, Object actionCommand) {
		this(analyseSIFrame, name, longDescription, actionCommand, null);
	}
	
	/**
	 * Le constructeur d'une Action.
	 * @param analyseSIFrame la fenêtre principale d'AnalyseSI
	 * @param name Le nom de l'action
	 * @param longDescription La description longue
	 * @param actionCommand La commande associée à l'action
	 * @param small_icon L'icone associée à l'action
	 */
	public AnalyseSIAction(AnalyseSIFrame analyseSIFrame, String name, String longDescription, Object actionCommand, ImageIcon small_icon) {
		this(analyseSIFrame, name, longDescription, actionCommand, small_icon, 0, null);
	}
	
	/**
	 * Le constructeur d'une Action.
	 * @param analyseSIFrame la fenêtre principale d'AnalyseSI
	 * @param name Le nom de l'action
	 * @param longDescription La description longue
	 * @param actionCommand La commande associée à l'action
	 * @param small_icon L'icone associée à l'action
	 * @param mnemonic Le mnemonic
	 * @param keyStroke Le raccourci clavier
	 */
	public AnalyseSIAction(AnalyseSIFrame analyseSIFrame, String name, String longDescription, Object actionCommand, ImageIcon small_icon,
			int mnemonic, KeyStroke keyStroke) {
		super(name, longDescription, actionCommand, small_icon, mnemonic, keyStroke);
		
		// Affectation des propriétés
		this.analyseSIFrame = analyseSIFrame;
		this.analyseSIApplication = analyseSIFrame.getApplication();
	}

	/**
	 * Retourne la fenêtre principale d'AnalyseSI.
	 * @return la fenêtre principale d'AnalyseSI
	 */
	public AnalyseSIFrame getAnalyseSIFrame() {
		return analyseSIFrame;
	}

	/**
	 * Retourne l'application principale d'AnalyseSI.
	 * @return l'application principale d'AnalyseSI
	 */
	public AnalyseSIApplication getAnalyseSIApplication() {
		return analyseSIApplication;
	}
}
