/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.action;

import java.awt.event.ActionEvent;
import java.awt.event.KeyEvent;

import javax.swing.JOptionPane;
import javax.swing.KeyStroke;

import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.eucalyptus.analysesi.gui.Messages;
import org.eucalyptus.analysesi.save.SaveModelException;
import org.eucalyptus.analysesi.save.SaveModelNotSupportedException;
import org.eucalyptus.egt.loader.ImageLoader;
import org.jdesktop.swingx.JXErrorPane;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Créer un nouveau fichier.
 *
 * @author Loic Dreux
 */
public class NewAction extends AnalyseSIAction {
	private final static Logger logger = LoggerFactory.getLogger(NewAction.class);

	/**
	 * Le constructeur {@link QuitAction}.
	 * 
	 * @param analyseSIFrame
	 *            La fenêtre principale d'AnalyseSI
	 */
	public NewAction(AnalyseSIFrame analyseSIFrame) {
		super(analyseSIFrame, Messages.getString("AnalyseSIActionsCollection.new"), Messages.getString("AnalyseSIActionsCollection.newLong"), CommandKey.NEW.name(), //$NON-NLS-1$ //$NON-NLS-2$
				ImageLoader.getInstance().getIcon("tango/22x22/actions/document-new.png"), 'n', KeyStroke.getKeyStroke(KeyEvent.VK_N, //$NON-NLS-1$
						ActionEvent.CTRL_MASK));
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		// Si le model a été modifié
		if (getAnalyseSIApplication().getSaveManager().isModified()) {
			int res = JOptionPane
					.showConfirmDialog(getAnalyseSIFrame(),
							"Voulez-vous sauvegarder le document existant ?",
							getAnalyseSIFrame().getTitle(), JOptionPane.YES_NO_CANCEL_OPTION);
			
			// En cas d'annulation
			if (res == JOptionPane.CANCEL_OPTION) {
				return;
			}
			
			// On sauvegarde le model
			if (res == JOptionPane.YES_OPTION) {
				try {
					getAnalyseSIApplication().getSaveManager().saveModel(getAnalyseSIFrame(), 
							getAnalyseSIApplication().getSaveManager().getCurrentAnalyseSIFile());
				} catch (SaveModelException e1) {
					logger.error(e1.getLocalizedMessage(), e1);
					JXErrorPane.showDialog(e1);
				} catch (SaveModelNotSupportedException e1) {
					logger.error(e1.getLocalizedMessage(), e1);
					JXErrorPane.showDialog(e1);
				}
			}
		}
		
		// Nouveau document
		getAnalyseSIFrame().getMeriseModel().clear();
	}
}
