/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.db;

import java.util.EventObject;
import java.util.List;

import org.eucalyptus.analysesi.db.DbConnectionParameters;

/**
 * Un évènement associé au composant {@link ConfiguredConnectionsList}.
 *
 * @author Loic Dreux
 */
public class ConnectionsEvent extends EventObject {
	/**
	 * La connection sélectionnée.
	 */
	private DbConnectionParameters selectedConnection;
	
	/**
	 * Les connections sauvegardées.
	 */
	private List<DbConnectionParameters> savedConnections;
	
	/**
	 * Le constructeur de l'objet {@link ConnectionsEvent}.
	 * @param selectedConnection La connection sélectionnée
	 */
	public ConnectionsEvent(Object source, DbConnectionParameters selectedConnection) {
		this(source, selectedConnection, null);
	}
	
	/**
	 * Le constructeur de l'objet {@link ConnectionsEvent}.
	 * @param savedConnections Les connection sauvegardée
	 */
	public ConnectionsEvent(Object source, List<DbConnectionParameters> savedConnections) {
		this(source, null, savedConnections);
	}
	
	/**
	 * Le constructeur de l'objet {@link ConnectionsEvent}.
	 * @param selectedConnection La connection sélectionnée
	 * @param savedConnections Les connections sauvegardée
	 */
	public ConnectionsEvent(Object source, DbConnectionParameters selectedConnection, List<DbConnectionParameters> savedConnections) {
		super(source);
		this.selectedConnection = selectedConnection;
		this.savedConnections = savedConnections;
	}

	/**
	 * Retoure la connection sélectionnée.
	 * @return the selectedConnection
	 */
	public DbConnectionParameters getSelectedConnection() {
		return selectedConnection;
	}

	/**
	 * Retourne les connections sauvegardées.
	 * @return the savedConnections
	 */
	public List<DbConnectionParameters> getSavedConnections() {
		return savedConnections;
	}
}
