/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.db;

import java.util.List;

import javax.swing.AbstractListModel;

import org.eucalyptus.analysesi.db.DbConnectionParameters;
import org.eucalyptus.analysesi.db.DbManager;

/**
 * Ce modèle gère les listes de connections.
 *
 * @author Loic Dreux
 */
public class ConnectionsModel extends AbstractListModel {
	/**
	 * Le gestionnaire de base de données.
	 */
	private DbManager dbManager;
	
	/**
	 * La liste des connections.
	 */
	private List<DbConnectionParameters> connections;

	/**
	 * Le constructeur de {@link ConnectionsModel}.
	 * 
	 * @param dbManager
	 *            Le gestionnaire de base de données.
	 */
	public ConnectionsModel(DbManager dbManager) {
		this.dbManager = dbManager;
		this.connections = dbManager.getConfiguredConnections();
	}

	/* (non-Javadoc)
	 * @see javax.swing.AbstractListModel#fireContentsChanged(java.lang.Object, int, int)
	 */
	@Override
	protected void fireContentsChanged(Object source, int index0, int index1) {
		fireUpdated();
		super.fireContentsChanged(source, index0, index1);
	}

	/* (non-Javadoc)
	 * @see javax.swing.AbstractListModel#fireIntervalAdded(java.lang.Object, int, int)
	 */
	@Override
	protected void fireIntervalAdded(Object source, int index0, int index1) {
		fireUpdated();
		super.fireIntervalAdded(source, index0, index1);
	}

	/* (non-Javadoc)
	 * @see javax.swing.AbstractListModel#fireIntervalRemoved(java.lang.Object, int, int)
	 */
	@Override
	protected void fireIntervalRemoved(Object source, int index0, int index1) {
		fireUpdated();
		super.fireIntervalRemoved(source, index0, index1);
	}
	
	/**
	 * Met à jour
	 */
	private void fireUpdated() {
		this.connections = dbManager.getConfiguredConnections();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.ListModel#getElementAt(int)
	 */
	@Override
	public Object getElementAt(int index) {
		return connections.get(index);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.ListModel#getSize()
	 */
	@Override
	public int getSize() {
		return connections.size();
	}

}
