/*
 * Copyright AnalyseSI, 2007
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.dictionary;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.swing.Action;
import javax.swing.BorderFactory;
import javax.swing.DefaultComboBoxModel;
import javax.swing.DefaultListCellRenderer;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JTextField;

import org.eucalyptus.analysesi.model.Attribute;
import org.eucalyptus.analysesi.model.MeriseModel;
import org.eucalyptus.analysesi.model.TypeAttribute;
import org.eucalyptus.analysesi.model.TypeAttributeLabel;
import org.eucalyptus.egt.factory.ActionFactory;
import org.eucalyptus.egt.loader.ImageLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;

/**
 * Le {@link JPanel} d'ajout d'attribut dans le dictionnaire
 * 
 * @author Loic DREUX
 */
public class DictionaryAddAttributePanel extends JPanel {
	private static Logger logger = LoggerFactory
			.getLogger(DictionaryAddAttributePanel.class);

	/**
	 * Le modèle merise.
	 */
	private MeriseModel meriseModel;

	/**
	 * Le modèle pour la table Dictionary.
	 */
	private DictionaryTableModel dictionaryTableModel;

	/**
	 * Le composant graphique pour le nom.
	 */
	private JTextField textFieldName;

	/**
	 * Le composant graphique pour la description.
	 */
	private JTextField textFieldDescription;

	/**
	 * Le composant graphique pour le type de base de données.
	 */
	private JTextField textFieldDatabase;

	/**
	 * Le composant graphique pour le type d'attribut
	 */
	private JComboBox comboBoxTypeAttribute;

	/**
	 * Le libellé de l'attribut 1
	 */
	private JLabel labelPropertyAttribute1;

	/**
	 * Le libellé de l'attribut 2
	 */
	private JLabel labelPropertyAttribute2;

	/**
	 * La liste des composants des propriétés du type d'attribut ajouté au panel
	 */
	private List<JComponent> componentsPropertiesTypeAttribute;

	/**
	 * Le builder
	 */
	private PanelBuilder builder;

	/**
	 * Les contraintes du builder
	 */
	private CellConstraints cc;

	/**
	 * Le panneau des propriétés
	 */
	private JPanel propertiesPanel;

	/**
	 * Ajouter un attribut
	 */
	private Action addAttribute;

	/**
	 * Fermer le panel
	 */
	private Action closeAction;

	/**
	 * Les listener de ce composant.
	 */
	private List<AddAttributePanelListener> addAttributePanelListeners;

	/**
	 * Le constructeur de la classe {@link DictionaryAddAttributePanel}.
	 * 
	 * @param meriseModel
	 *            le modèle merise
	 */
	public DictionaryAddAttributePanel(
			DictionaryTableModel dictionaryTableModel, MeriseModel meriseModel) {
		this.dictionaryTableModel = dictionaryTableModel;
		this.meriseModel = meriseModel;
		this.componentsPropertiesTypeAttribute = new ArrayList<JComponent>();
		this.addAttributePanelListeners = new ArrayList<AddAttributePanelListener>();

		// Initialisations des actions et de l'interface
		this.initActions();
		this.initGui();

		// On initialise les composants propriétés
		this.updatePropertiesTypeAttribute();
	}

	/**
	 * Ajoute un listener.
	 * @param listener le listener à ajouter
	 */
	public void addAddAttributePanelListener(AddAttributePanelListener listener) {
		addAttributePanelListeners.add(listener);
	}

	/**
	 * Supprime un listener
	 * @param listener le listener à supprimer
	 */
	public void removeAddAttributePanelListener(
			AddAttributePanelListener listener) {
		addAttributePanelListeners.remove(listener);
	}

	/**
	 * Retourne le modèle du dictionnaire.
	 * 
	 * @return le modèle du dictionnaire.
	 */
	public DictionaryTableModel getDictionaryTableModel() {
		return dictionaryTableModel;
	}

	/**
	 * Retourne le modèle merise.
	 * 
	 * @return le modèle merise
	 */
	public MeriseModel getMeriseModel() {
		return meriseModel;
	}

	/**
	 * Initialise le composant pour la saisie
	 */
	public void init() {
		this.textFieldName.requestFocus();
	}

	/**
	 * Initialisation des différentes actions disponible pour le
	 * {@link DictionaryPanel}.
	 */
	private void initActions() {
		addAttribute = ActionFactory
				.buildAction("Ajouter", "Ajouter l'attribut", "ADD_ATTRIBUTE",
						new AddAttributHandler());
		closeAction = ActionFactory.buildAction("", "Fermer", "CLOSE",
				ImageLoader.getInstance().getIcon(
						"tango/22x22/actions/window-close.png"), new CloseHandler());
	}

	/**
	 * Initialisation du composant graphique.
	 */
	private void initGui() {
		// Ajout d'une information
		FormLayout layout = new FormLayout(
				"right:p, 5px, 150px, 10px, right:p, 5px, 150px",
				"25px, 5px, 25px, 5px, 25px, 5px, 25px, 5px, 25px, 5px, p");
		this.builder = new PanelBuilder(layout);
		builder.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
		cc = new CellConstraints();

		// Nom
		textFieldName = new JTextField();
		textFieldName.requestFocus();
		builder.addLabel("Nom", cc.xy(1, 1));
		builder.add(textFieldName, cc.xy(3, 1));

		// Description
		textFieldDescription = new JTextField();
		builder.addLabel("Description", cc.xy(1, 3));
		builder.add(textFieldDescription, cc.xy(3, 3));

		// Bouton ajouter
		builder.add(new JButton(addAttribute), cc.xyw(1, 11, 3));

		// Type Bdd
		textFieldDatabase = new JTextField();
		textFieldDatabase.setEnabled(false);
		textFieldDatabase.setText(this.meriseModel.getDatabase().getName());
		builder.addLabel("SGBD :", cc.xy(5, 1));
		builder.add(textFieldDatabase, cc.xy(7, 1));

		// Type
		comboBoxTypeAttribute = new JComboBox(new DefaultComboBoxModel(
				this.meriseModel.getDatabase().getTypeAttributeClassList()
						.toArray()));
		comboBoxTypeAttribute.setRenderer(new TypeAttributeRender(
				this.meriseModel.getDatabase().getTypeAttributeClassList()));
		comboBoxTypeAttribute.addActionListener(new TypeAttributeHandler());
		builder.addLabel("Type de l'attribut :", cc.xy(5, 3));
		builder.add(comboBoxTypeAttribute, cc.xy(7, 3));

		// Propriété 1
		labelPropertyAttribute1 = new JLabel("");
		builder.add(labelPropertyAttribute1, cc.xy(5, 5));

		// Propriété 2
		labelPropertyAttribute2 = new JLabel("");
		builder.add(labelPropertyAttribute2, cc.xy(5, 7));

		this.setLayout(new BorderLayout());
		this.propertiesPanel = builder.getPanel();
		this.add(this.propertiesPanel, BorderLayout.CENTER);
		this.add(new JPanel(new FlowLayout()) {
			{
				this.add(new JButton(closeAction));
			}
		}, BorderLayout.EAST);

	}

	/**
	 * Modifie le DictionaryModel.
	 * 
	 * @param dictionaryTableModel
	 */
	void setDictionaryTableModel(DictionaryTableModel dictionaryTableModel) {
		this.dictionaryTableModel = dictionaryTableModel;
	}

	/**
	 * Modifie le modèle merise.
	 * 
	 * @param meriseModel
	 */
	void setMeriseModel(MeriseModel meriseModel) {
		this.meriseModel = meriseModel;
	}

	/**
	 * Met à jour les propriétés des attributs
	 */
	@SuppressWarnings("unchecked")
	public void updatePropertiesTypeAttribute() {
		logger
				.debug("Mise à jour des composants associés aux propriétés du type d'attribut");
		Class<? extends TypeAttribute> clazz = (Class<? extends TypeAttribute>) comboBoxTypeAttribute
				.getSelectedItem();

		// Récupération des composants et des libellés
		List<JComponent> components = PropertiesTypeAttributeComponentFactory
				.buildComponents(clazz);
		List<String> labels = PropertiesTypeAttributeComponentFactory
				.getFieldsName(clazz);

		// On nettoie les composants existans
		for (JComponent component : componentsPropertiesTypeAttribute)
			this.propertiesPanel.remove(component);

		// On ajoute les composants
		int y = 5;
		for (JComponent component : components) {
			logger.debug("Ajout du composant : " + component);
			this.builder.add(component, cc.xy(7, y));
			componentsPropertiesTypeAttribute.add(component);
			y += 2;
		}

		// Mise à jour des libellés
		labelPropertyAttribute2
				.setText(labels.size() >= 2 ? labels.get(1) : "");
		labelPropertyAttribute1
				.setText(labels.size() >= 1 ? labels.get(0) : "");

		// On revalide le tout et on repaint
		this.revalidate();
		this.repaint();
	}

	/**
	 * Le Handler qui gère l'ajout d'un attribut.
	 * 
	 * @author Loic Dreux
	 */
	private class AddAttributHandler implements ActionListener {
		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent
		 * )
		 */
		@SuppressWarnings("unchecked")
		@Override
		public void actionPerformed(ActionEvent e) {
			// On test le nom de l'attribut
			if (textFieldName.getText().equals("")) {
				// messenger.severe("Renseignez le nom de l'attribut");
				textFieldName.requestFocus();
				return;
			}

			// On ajoute l'information
			Attribute attribute = new Attribute();
			attribute.setName(textFieldName.getText());
			attribute.setDescription(textFieldDescription.getText());
			Class<? extends TypeAttribute> selectedItem = (Class<? extends TypeAttribute>) comboBoxTypeAttribute
					.getSelectedItem();
			attribute.setType(PropertiesTypeAttributeComponentFactory
					.buildTypeAttribute(selectedItem,
							componentsPropertiesTypeAttribute));
			dictionaryTableModel.addInformation(attribute);

			// On vide les champs
			textFieldName.setText("");
			textFieldDescription.setText("");
			comboBoxTypeAttribute.setSelectedIndex(0);
			updatePropertiesTypeAttribute();
			textFieldName.requestFocus();

			// On affiche le message de succés
			// messenger.ok("L'attribut a été ajouté avec succès");
		}
	}

	/**
	 * Le listener du composant Liste déroulante des types d'attribut
	 * 
	 * @author Loic Dreux
	 */
	private class TypeAttributeHandler implements ActionListener {

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent
		 * )
		 */
		public void actionPerformed(ActionEvent e) {
			logger.debug("Evènements sur la liste des Type d'attribut");
			DictionaryAddAttributePanel.this.updatePropertiesTypeAttribute();
		}

	}

	/**
	 * Fermeture du Panel.
	 * 
	 * @author Loic Dreux
	 */
	private class CloseHandler implements ActionListener {

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent
		 * )
		 */
		@Override
		public void actionPerformed(ActionEvent e) {
			AddAttributePanelEvent evt = new AddAttributePanelEvent(DictionaryAddAttributePanel.this);
			
			// On prévient tous les listeners
			for(AddAttributePanelListener listener: addAttributePanelListeners) {
				listener.addAttributePanelClosed(evt);
			}
		}

	}

	/**
	 * L'afficheur du combobox des types d'attribut.
	 * 
	 * @author Loic DREUX
	 */
	private class TypeAttributeRender extends DefaultListCellRenderer {

		/**
		 * La Map qui associe la classe du type de l'attribut de son label.
		 */
		private Map<Class<? extends TypeAttribute>, String> titlesMap;

		/**
		 * Le constructeur de la classe {@link TypeAttributeRender}.
		 * 
		 * @param listClass
		 */
		public TypeAttributeRender(
				List<Class<? extends TypeAttribute>> listClass) {
			this.titlesMap = new HashMap<Class<? extends TypeAttribute>, String>();

			for (Class<? extends TypeAttribute> clazz : listClass) {
				TypeAttributeLabel a = clazz
						.getAnnotation(TypeAttributeLabel.class);
				if (a != null) {
					titlesMap.put(clazz, a.value());
				} else {
					titlesMap.put(clazz, clazz.getCanonicalName());
				}
			}
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * javax.swing.DefaultListCellRenderer#getListCellRendererComponent(
		 * javax.swing.JList, java.lang.Object, int, boolean, boolean)
		 */
		public Component getListCellRendererComponent(JList list, Object value,
				int index, boolean isSelected, boolean cellHasFocus) {
			super.getListCellRendererComponent(list, value, index, isSelected,
					cellHasFocus);
			this.setText(titlesMap.get(value));
			return this;
		}
	}

}
