/*
 * Copyright AnalyseSI, 2007
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.dictionary;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.Action;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JToolBar;
import javax.swing.UIManager;

import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.eucalyptus.analysesi.gui.AnalyseSIPanel;
import org.eucalyptus.analysesi.gui.event.AnalyseSIEvent;
import org.eucalyptus.analysesi.gui.event.AnalyseSIListener;
import org.eucalyptus.egt.factory.ActionFactory;
import org.eucalyptus.egt.loader.ImageLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * La classe {@link JPanel} contient l'éditeur du Dictionnaire des Informations.
 * 
 * @author Loic DREUX
 */
public class DictionaryPanel extends AnalyseSIPanel implements
		AnalyseSIListener, AddAttributePanelListener {
	@SuppressWarnings("unused")
	private static Logger logger = LoggerFactory
			.getLogger(DictionaryPanel.class);

	/**
	 * Le dictionnaire des informations
	 */
	private DictionaryTableModel dictionaryTableModel;

	/**
	 * L'action afficher le panel d'ajout d'info
	 */
	private Action showAddAttributePanelAction;

	/**
	 * La table
	 */
	private JTable dictionaryTable;

	/**
	 * La toolbar
	 */
	private JComponent toolbar;

	/**
	 * Le panel
	 */
	private DictionaryAddAttributePanel dictionaryAddAttributePanel;

	/**
	 * Le composant du Sud.
	 */
	private JComponent visibleSouthComponent;

	// Messager
	// private Messenger messenger;

	/**
	 * Le constructeur de la classe {@link DictionaryPanel}.
	 * 
	 * @param analyseSIFrame
	 *            La fenêtre principale d'AnalyseSI
	 * @param MeriseModel
	 *            le modèle merise
	 */
	public DictionaryPanel(AnalyseSIFrame analyseSIFrame) {
		super(analyseSIFrame, "DICTIONARY");

		// Initialisation des propriétés
		this.dictionaryTableModel = new DictionaryTableModel(analyseSIFrame.getMeriseModel()
				.getDictionary());

		// Initialisations des actions et de l'interface
		this.initActions();
		this.initGui();
	}

	/**
	 * Initialisation des différentes actions disponible pour le
	 * {@link DictionaryPanel}.
	 */
	private void initActions() {
		this.showAddAttributePanelAction = ActionFactory.buildAction("Ajouter",
				"Ajouter un attribut", "SHOW_ADD_ATTRIBUTE_PANEL", ImageLoader
						.getInstance().getIcon(
								"tango/22x22/actions/list-add.png"), 0, null,
				new ShowAddAttributePanelHandler());
	}

	/**
	 * Initialisation de l'interface du {@link DictionaryPanel}.
	 */
	private void initGui() {
		// Panel
		this.setLayout(new BorderLayout());

		// Table
		dictionaryTable = new JTable(dictionaryTableModel);
		this.add(new JScrollPane(dictionaryTable), BorderLayout.CENTER);

		// TabledPane : Ajout/Modif des Informations
		dictionaryAddAttributePanel = new DictionaryAddAttributePanel(
				dictionaryTableModel, getAnalyseSIFrame().getMeriseModel());
		dictionaryAddAttributePanel.addAddAttributePanelListener(this);

		visibleSouthComponent = null;

		// ToolBar
		toolbar = new JToolBar();
		toolbar.setBackground(UIManager.getColor("JPanel.background"));
		toolbar.add(new JButton(showAddAttributePanelAction));
		
		this.add(toolbar, BorderLayout.NORTH);
	}

	/**
	 * Affiche/Cache le panel du bas.
	 */
	public void showHideBottomPanel() {
		if (visibleSouthComponent == null) {
			visibleSouthComponent = dictionaryAddAttributePanel;
			this.add(dictionaryAddAttributePanel, BorderLayout.SOUTH);
		} else {
			this.remove(dictionaryAddAttributePanel);
			visibleSouthComponent = null;
		}
		revalidate();
		repaint();
	}

	/**
	 * Affiche le panel pour ajouter un attribut
	 * 
	 * @author Loic Dreux
	 */
	private class ShowAddAttributePanelHandler implements ActionListener {

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent
		 * )
		 */
		@Override
		public void actionPerformed(ActionEvent e) {
			if (visibleSouthComponent == null) {
				visibleSouthComponent = dictionaryAddAttributePanel;
				DictionaryPanel.this.add(dictionaryAddAttributePanel,
						BorderLayout.SOUTH);
				revalidate();
				repaint();
			}
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eucalyptus.analysesi.gui.event.AnalyseSIListener#meriseModelChanged
	 * (org.eucalyptus.analysesi.gui.event.AnalyseSIEvent)
	 */
	@Override
	public void meriseModelChanged(AnalyseSIEvent e) {
		dictionaryTableModel = new DictionaryTableModel(e.getMeriseModel()
				.getDictionary());
		dictionaryTable.setModel(dictionaryTableModel);
		dictionaryAddAttributePanel.setMeriseModel(e.getMeriseModel());
		dictionaryAddAttributePanel
				.setDictionaryTableModel(dictionaryTableModel);
	}

	/* (non-Javadoc)
	 * @see org.eucalyptus.analysesi.gui.dictionary.AddAttributePanelListener#addAttributePanelClosed(org.eucalyptus.analysesi.gui.dictionary.AddAttributePanelEvent)
	 */
	@Override
	public void addAttributePanelClosed(AddAttributePanelEvent e) {
		if (visibleSouthComponent != null) {
			remove(visibleSouthComponent);
			visibleSouthComponent = null;
			revalidate();
			repaint();
		}
	}
}
