/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.dictionary;

import javax.swing.table.AbstractTableModel;

import org.eucalyptus.analysesi.model.Attribute;
import org.eucalyptus.analysesi.model.Dictionary;


/**
 * 
 *
 * @author Loic Dreux
 */
public class DictionaryTableModel extends AbstractTableModel {

	private Dictionary dictionary;

	private final String[] columnNames = { "Nom", "Description", "Entité", "Type"};
	private final Class<?>[] columnClass = { String.class, String.class, String.class, String.class };

	/**
	 * @param dictionary
	 */
	public DictionaryTableModel(Dictionary dictionary) {
		this.dictionary = dictionary;
		//dictionary.addDictionaryListener(this);
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getColumnCount()
	 */
	public int getColumnCount() {
		return columnNames.length;
	}

	@Override
	public Class<?> getColumnClass(int arg0) {
		return columnClass[arg0];
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.AbstractTableModel#getColumnName(int)
	 */
	@Override
	public String getColumnName(int arg0) {
		return columnNames[arg0];
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getRowCount()
	 */
	public int getRowCount() {
		return dictionary.size();
	}

	/* (non-Javadoc)
	 * @see javax.swing.table.TableModel#getValueAt(int, int)
	 */
	public Object getValueAt(int row, int column) {
		Attribute attribute = dictionary.get(row);
		
		switch (column)
		{
		case 0:
			return attribute.getName();
		case 1:
			return attribute.getDescription();
		case 2:
			return "";
		case 3:
			return attribute.getType();
		}
		return "";
	}
	
	/* (non-Javadoc)
	 * @see javax.swing.table.AbstractTableModel#setValueAt(java.lang.Object, int, int)
	 */
	@Override
	public void setValueAt(Object value, int row, int column) {
		Attribute attribute = dictionary.get(row);
		
		switch (column)
		{
		case 0:
			attribute.setName((String)value);
			break;
		case 1:
			attribute.setDescription((String)value);
			break;
		}
	}
	
	/* (non-Javadoc)
	 * @see javax.swing.table.AbstractTableModel#isCellEditable(int, int)
	 */
	@Override
	public boolean isCellEditable(int rowIndex, int columnIndex) {
		switch (columnIndex)
		{
		case 0:
			return true;
		case 1:
			return true;
		case 3:
			return false;
		}
		return false;
	}

	/**
	 * @param information
	 */
	public void addInformation(Attribute information) {
		dictionary.add(information);
		fireTableDataChanged();
	}

	/**
	 * @param information
	 */
	public void removeInformation(Attribute information) {
		dictionary.remove(information);
		fireTableDataChanged();
	}

	/**
	 * 
	 */
	public void informationListChanged()
	{
		fireTableDataChanged();
	}
}
