/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.factory;

import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;

import org.eucalyptus.analysesi.gui.Messages;
import org.eucalyptus.analysesi.gui.action.ActionsCollection;
import org.eucalyptus.analysesi.gui.action.CommandKey;

/**
 * La fabrique de menu pour AnalyseSI.
 * 
 * @author Loic Dreux
 */
public class MenuFactory {

	/**
	 * Fabrique le menu pour la fenêtre principale d'AnalyseSI.
	 * 
	 * @param actionsCollection
	 *            la collection des actions
	 * @return le menu pour la fenêtre principale d'AnalyseSI
	 */
	public static JMenuBar buildMenu(ActionsCollection actionsCollection) {
		JMenuBar menuBar = new JMenuBar();

		JMenu menu;
		JMenuItem menuItem;

		// Menu File
		menu = new JMenu(Messages.getString("AnalyseSIMenu.file")); //$NON-NLS-1$
		menu.setMnemonic('f');

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.NEW));
		menu.add(menuItem);

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.OPEN));
		menu.add(menuItem);

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.SAVE));
		menu.add(menuItem);

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.SAVEAS));
		menu.add(menuItem);

		menu.addSeparator();

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.QUIT));
		menu.add(menuItem);

		// Menu edition

		menuBar.add(menu);

		menu = new JMenu(Messages.getString("AnalyseSIMenu.edition")); //$NON-NLS-1$
		menu.setMnemonic('e');

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.UNDO));
		menu.add(menuItem);

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.REDO));
		menu.add(menuItem);

		menu.addSeparator();

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.CUT));
		menu.add(menuItem);

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.COPY));
		menu.add(menuItem);

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.PASTE));
		menu.add(menuItem);

		menuBar.add(menu);

		// Menu tools

		menu = new JMenu("Outil");
		menu.setMnemonic('o');

		menuItem = new JMenuItem(actionsCollection
				.getAction(CommandKey.OPEN_REVERSE_DIALOG));
		menu.add(menuItem);

		menu.addSeparator();

		menuItem = new JMenuItem(actionsCollection
				.getAction(CommandKey.OPEN_PLUGINS_DIALOG));
		menu.add(menuItem);

		menuBar.add(menu);

		// Menu about

		menu = new JMenu(Messages.getString("AnalyseSIMenu.help")); //$NON-NLS-1$
		menu.setMnemonic('a');

		menuItem = new JMenuItem(actionsCollection.getAction(CommandKey.ABOUT));
		menu.add(menuItem);

		menuBar.add(menu);

		return menuBar;
	}

	/**
	 * Fabrique un menu volant pour les copié-collé.
	 * @param actionsCollection La collection d'actions
	 * @param cut Affiche le menu coupé
	 * @param copy Affiche le menu copié
	 * @param paste Affiche le menu Coller
	 * @return Le menu volant
	 */
	public JPopupMenu buildClipboardPopupMenu(ActionsCollection actionsCollection, boolean cut, boolean copy, boolean paste)
    {
		JPopupMenu menu = new JPopupMenu();
        JMenuItem menuItem;

        if (cut) {
            menuItem = new JMenuItem(actionsCollection
                    .getAction(CommandKey.CUT));
            menu.add(menuItem);
        }

        if (copy) {
            menuItem = new JMenuItem(actionsCollection
                    .getAction(CommandKey.COPY));
            menu.add(menuItem);
        }

        if (paste) {
            menuItem = new JMenuItem(actionsCollection
                    .getAction(CommandKey.PASTE));
            menu.add(menuItem);
        }
        
        return menu;
    }
}