/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.graph;

import java.util.HashMap;
import java.util.Map;

import org.eucalyptus.analysesi.model.Entity;
import org.eucalyptus.analysesi.model.MCD;
import org.eucalyptus.analysesi.model.Relation;
import org.eucalyptus.egt.egraph.DefaultGraphModel;
import org.eucalyptus.egt.egraph.GraphModel;
import org.eucalyptus.egt.egraph.Link;

/**
 * Ce {@link GraphModel} est utilisé pour affiché le MCD.
 *
 * @author Loic Dreux
 */
public class McdGraphModel extends DefaultGraphModel {
	/**
	 * Le modèle MCD
	 */
	private MCD mcd;
	
	/**
	 * La correspondance Entity - Cell 
	 */
	private Map<Entity, EntityCell> entityCellMap;
	
	/**
	 * La correspondance Relation - Cell
	 */
	private Map<Relation, RelationCell> relationCellMap;
	
	/**
	 * Le constructeur du {@link McdGraphModel}.
	 * @param mcd Le mcd associé à ce modèle
	 */
	public McdGraphModel(MCD mcd) {
		this.mcd = mcd;
		this.entityCellMap = new HashMap<Entity, EntityCell>();
		this.relationCellMap = new HashMap<Relation, RelationCell>();
		this.initModel();
	}
	
	/**
	 * Initialise le modèle.
	 */
	private void initModel() {
		// Initialisation des entités
		for (Entity entity: mcd.getEntities()) {
			EntityCell entityCell = new EntityCell(entity);
			entityCellMap.put(entity, entityCell);
			this.cells.add(entityCell);
		}
		
		// Initialisation des relations et des liens
		for (Relation relation: mcd.getRelations()) {
			RelationCell relationCell = new RelationCell(relation);
			relationCellMap.put(relation, relationCell);
			this.cells.add(relationCell);
			for(Link<?, ?> link: relationCell.getLinks()) {
				this.links.add(link);
			}
		}
	}
	
	/**
	 * Retourne la cellule associée à l'entité.
	 * @param entity l'entité
	 * @return la cellule associée à l'entité
	 */
	public EntityCell getEntityCell(Entity entity) {
		return entityCellMap.get(entity);
	}
	
	/**
	 * Retourne la cellule associée à l'association.
	 * @param relation l'association
	 * @return la cellule associée à l'association
	 */
	public RelationCell getRelationCell(Relation relation) {
		return relationCellMap.get(relation);
	}
}
