/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.graph;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.geom.Line2D;

import org.eucalyptus.egt.Graph;
import org.eucalyptus.egt.egraph.Link;
import org.eucalyptus.egt.egraph.LinkRenderer;

/**
 * Affiche un lien entre une entité et une relation
 *
 * @author Loic Dreux
 */
public class McdLinkRenderer implements LinkRenderer {

	/* (non-Javadoc)
	 * @see org.eucalyptus.egt.egraph.LinkRenderer#paint(org.eucalyptus.egt.egraph.Link, java.awt.Graphics)
	 */
	@Override
	public void paint(Graph graph, Link<?, ?> link, Graphics g) {
		McdLink mcdLink = (McdLink)link;
		
		Graphics2D g2d = (Graphics2D) g;
		
		// On calcul les dimensions
		Point positionEntityCell = mcdLink.getFirstCell().getPosition();
		Dimension sizeEntityCell = graph.getCellRenderer(mcdLink.getFirstCell().getClass()).getSize(graph, mcdLink.getFirstCell(), g);
		Point positionRelationCell = mcdLink.getSecondCell().getPosition();
		Dimension sizeRelationCell = graph.getCellRenderer(mcdLink.getFirstCell().getClass()).getSize(graph, mcdLink.getFirstCell(), g);
		
		// Calcul des centres
		Point p1 = new Point(positionEntityCell.x + sizeEntityCell.width / 2, positionEntityCell.y + sizeEntityCell.height / 2);
		Point p2 = new Point(positionRelationCell.x + sizeRelationCell.width / 2, positionRelationCell.y + sizeRelationCell.height / 2);
		
		// Affichage
		Line2D line2D = new Line2D.Double(p1, p2);
		g.setColor(Color.BLACK);
		g2d.draw(line2D);
	}
}
