/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.graph;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.Stroke;
import java.awt.geom.RoundRectangle2D;

import org.eucalyptus.analysesi.model.Attribute;
import org.eucalyptus.analysesi.model.Relation;
import org.eucalyptus.egt.Graph;
import org.eucalyptus.egt.egraph.Cell;
import org.eucalyptus.egt.egraph.CellRenderer;

/**
 * Affiche une cellule {@link Relation}.
 * 
 * @author Loic Dreux
 */
public class RelationCellRenderer implements CellRenderer {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eucalyptus.egt.egraph.CellRenderer#getSize(org.eucalyptus.egt.egraph
	 * .Cell, java.awt.Graphics)
	 */
	@Override
	public Dimension getSize(Graph graph, Cell cell, Graphics g) {
		RelationCell relationCell = (RelationCell) cell;

		// La taille dépend du titre
		double width = g.getFontMetrics().getStringBounds(
				relationCell.getRelation().getName(), g).getWidth() + 10;
		double height = g.getFontMetrics().getHeight() + 15;

		// Mais aussi des attributs
		for (Attribute attribute : relationCell.getRelation().getAttributes()) {
			double tempWidth = g.getFontMetrics().getStringBounds(
					attribute.getName(), g).getWidth() + 10;
			if (tempWidth > width) {
				width = tempWidth;
			}
		}
		height += relationCell.getRelation().sizeAttributes()
				* g.getFontMetrics().getHeight();

		return new Dimension((int) width, (int) height);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eucalyptus.egt.egraph.CellRenderer#paint(org.eucalyptus.egt.egraph
	 * .Cell, java.awt.Graphics)
	 */
	@Override
	public void paint(Graph graph, Cell cell, Graphics g) {
		RelationCell relationCell = (RelationCell) cell;

		Graphics2D g2d = (Graphics2D) g;
		RoundRectangle2D r;
		Dimension size = this.getSize(graph, relationCell, g);

		// Création du rectangle
		r = new RoundRectangle2D.Double(relationCell.getPosition().x,
				relationCell.getPosition().y, size.width, size.height, 35, 35);

		// Dessin de l'ombre
		paintBorderShadow(relationCell, r, g2d, 6, size);

		// Ecriture du fond
		g2d.setColor(Color.WHITE);
		g2d.fill(r);

		// Ecriture du contour
		g2d.setColor(Color.BLUE);
		g2d.draw(r);

		// Ecriture de la séparation
		g2d.drawLine(relationCell.getPosition().x, relationCell.getPosition().y
				+ g.getFontMetrics().getHeight() + 5, relationCell
				.getPosition().x
				+ size.width, relationCell.getPosition().y
				+ g.getFontMetrics().getHeight() + 5);

		// Ecriture du titre
		g2d.setColor(Color.BLACK);
		g2d.drawString(relationCell.getRelation().getName(), relationCell
				.getPosition().x + 5, relationCell.getPosition().y
				+ g.getFontMetrics().getHeight());

		// Ecriture des attributs
		int i = 0;
		for (Attribute attribute : relationCell.getRelation().getAttributes()) {
			g2d.drawString(attribute.getName(),
					relationCell.getPosition().x + 5, relationCell
							.getPosition().y
							+ g.getFontMetrics().getHeight() * (i + 2) + 5);
			i++;
		}
	}

	private static Color getMixedColor(Color c1, float pct1, Color c2,
			float pct2) {
		float[] clr1 = c1.getComponents(null);
		float[] clr2 = c2.getComponents(null);
		for (int i = 0; i < clr1.length; i++) {
			clr1[i] = (clr1[i] * pct1) + (clr2[i] * pct2);
		}
		return new Color(clr1[0], clr1[1], clr1[2], clr1[3]);
	}

	private void paintBorderShadow(RelationCell relationCell,
			RoundRectangle2D r, Graphics2D g2, int shadowWidth, Dimension size) {
		g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
				RenderingHints.VALUE_ANTIALIAS_ON);
		Stroke stroke = g2.getStroke();
		r = new RoundRectangle2D.Double(r.getX() + 2, r.getY() + 2, r
				.getWidth() - 2, r.getHeight() - 2, 35, 35);

		int sw = shadowWidth * 2;
		for (int i = sw; i >= 2; i -= 2) {
			float pct = (float) (sw - i) / (sw - 1);
			g2.setColor(getMixedColor(Color.LIGHT_GRAY, pct, Color.WHITE,
					1.0f - pct));
			g2.setStroke(new BasicStroke(i));
			g2.draw(r);
		}

		g2.setStroke(stroke);
	}
}
