/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.help;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.InputStream;

import javax.swing.JComponent;
import javax.swing.JScrollPane;
import javax.swing.JToolBar;
import javax.swing.SwingWorker;

import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.eucalyptus.analysesi.gui.AnalyseSIPanel;
import org.eucalyptus.analysesi.gui.Messages;
import org.eucalyptus.egt.EgtProperties;
import org.eucalyptus.egt.EgtPropertyKeys;
import org.eucalyptus.egt.action.EucalyptusAction;
import org.eucalyptus.egt.loader.ImageLoader;
import org.eucalyptus.egt.loader.ResourceLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.xhtmlrenderer.simple.XHTMLPanel;

/**
 * Ce panel affiche l'aide dans l'application AnalyseSI.
 * 
 * @author Loic Dreux
 */
public class HelpPanel extends AnalyseSIPanel {
	// Le logger
	@SuppressWarnings("unused")//$NON-NLS-1$
	private static final Logger logger = LoggerFactory
			.getLogger(ImageLoader.class);

	/**
	 * L'action retour en arrière
	 */
	private EucalyptusAction goback;
	
	/**
	 * L'action retour en avant
	 */
	private EucalyptusAction gonext;

	/**
	 * L'action page d'acceuil.
	 */
	private EucalyptusAction home;

	/**
	 * Le panneau qui affiche l'aide.
	 */
	private XHTMLPanel xhtmlPanel;

	/**
	 * Le gestionnaire d'actions
	 */
	private ActionHandler actionHandler;

	/**
	 * Le constructeur du {@link HelpPanel}.
	 */
	public HelpPanel(AnalyseSIFrame analyseSIFrame) {
		super(analyseSIFrame, "HELP"); //$NON-NLS-1$

		// Initialise les actions
		initActions();

		// Création du panel
		xhtmlPanel = new XHTMLPanel();

		// Chargement du document
		SwingWorker<Object, Object> sw = new SwingWorker<Object, Object>() {
			@Override
			public Object doInBackground() {
				try {
					// Ouverture du flux AnalyseSI.html
					InputStream inputStream = ResourceLoader.getInstance()
							.getHtmlResourceAsStream("AnalyseSI.html"); //$NON-NLS-1$
					xhtmlPanel.setDocument(inputStream, EgtProperties
							.getProperty(EgtPropertyKeys.HTML_DATA_FOLDER));
				} catch (Exception e) {
					e.printStackTrace();
				}
				return null;
			}
		};
		sw.execute();

		this.setLayout(new BorderLayout());
		this.add(BorderLayout.CENTER, new JScrollPane(xhtmlPanel));
		this.add(BorderLayout.NORTH, buildToolbar());
	}

	/**
	 * Fabrique la barre d'outil.
	 * 
	 * @return la barre d'outil
	 */
	private JComponent buildToolbar() {
		JToolBar toolbar = new JToolBar();

		toolbar.add(goback);
		toolbar.add(gonext);
		toolbar.add(home);
		return toolbar;
	}

	/**
	 * Initialise les actions.
	 */
	private void initActions() {
		actionHandler = new ActionHandler();

		goback = new EucalyptusAction(
				Messages.getString("HelpPanel.previous"), Messages.getString("HelpPanel.prevousLong"), Actions.BACK.name(), ImageLoader.getInstance().getIcon( //$NON-NLS-1$ //$NON-NLS-2$
								"tango/22x22/actions/go-previous.png"), 0, null); //$NON-NLS-1$
		goback.addActionListener(actionHandler);
		gonext = new EucalyptusAction(
				"Suivant", "Suivant", Actions.NEXT.name(), ImageLoader.getInstance().getIcon(
								"tango/22x22/actions/go-next.png"), 0, null); //$NON-NLS-1$
		gonext.addActionListener(actionHandler);
		home = new EucalyptusAction(
				Messages.getString("HelpPanel.home"), Messages.getString("HelpPanel.homeLong"), Actions.HOME.name(), ImageLoader.getInstance().getIcon( //$NON-NLS-1$ //$NON-NLS-2$
								"tango/22x22/actions/go-home.png"), 0, null); //$NON-NLS-1$
		home.addActionListener(actionHandler);
	}

	/**
	 * Le gestionnaire d'actions.
	 * 
	 * @author Loic Dreux
	 */
	private class ActionHandler implements ActionListener {
		public void actionPerformed(ActionEvent e) {
			String action = e.getActionCommand();

			if (action.equals(Actions.BACK.name())) {
				// TODO Ecrire l'action retour en arrière
			}
			if (action.equals(Actions.HOME.name())) {
				// TODO Ecrire l'action Page d'acceuil
			}
		}
	}

	/**
	 * La liste des actions locales.
	 * 
	 * @author Loic Dreux
	 */
	private enum Actions {
		/**
		 * Retour en arrière.
		 */
		BACK,

		/**
		 * Retour en avant 
		 */
		NEXT,
		
		/**
		 * Page d'acceuil.
		 */
		HOME
		
	}
}