/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.mcd;

import java.awt.BorderLayout;

import javax.swing.JComponent;
import javax.swing.JToolBar;
import javax.swing.UIManager;

import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.eucalyptus.analysesi.gui.AnalyseSIPanel;
import org.eucalyptus.analysesi.gui.dictionary.DictionaryPanel;
import org.eucalyptus.analysesi.gui.event.AnalyseSIEvent;
import org.eucalyptus.analysesi.gui.event.AnalyseSIListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


public class MCDPanel extends AnalyseSIPanel implements AnalyseSIListener {
	@SuppressWarnings("unused")
	private static Logger logger = LoggerFactory.getLogger(MCDPanel.class);
	
	/**
	 * La toolbar
	 */
	private JComponent toolbar;
	
	public MCDPanel(AnalyseSIFrame analyseSIFrame) {
		super(analyseSIFrame, "MCD");

		// Initialisation des propriétés


		// Initialisations des actions et de l'interface
		this.initActions();
		this.initGui();
		
	}
	
	/**
	 * Initialisation des différentes actions disponible pour le
	 * {@link DictionaryPanel}.
	 */
	private void initActions() {
		
	}
	
	/**
	 * Initialisation de l'interface du {@link DictionaryPanel}.
	 */
	private void initGui() {
		// Panel
		this.setLayout(new BorderLayout());

		// ToolBar
		toolbar = new JToolBar();
		toolbar.setBackground(UIManager.getColor("JPanel.background"));

		this.add(toolbar, BorderLayout.NORTH);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eucalyptus.analysesi.gui.event.AnalyseSIListener#meriseModelChanged
	 * (org.eucalyptus.analysesi.gui.event.AnalyseSIEvent)
	 */
	@Override
	public void meriseModelChanged(AnalyseSIEvent e) {
		
	}
}
    /*private ActionHandler actionHandler;

    private BasicAction addEntite, addAssociation, addLien;

    private BasicAction delLien, delObjet;

    private BasicAction modEntite, modAssociation, modLien;

    private BasicAction verif, buildMLD;

    private BasicAction saveGraphic;

    private SQLCommand sqlCommand;

    private JPanel toolbar;

    private JPopupMenu popupLien, popupEntite, popupAssociation,
            popupSaveGraphic;

    private JFileChooser chooser;

    private JToggleButton btnLien;

    private EntiteDialog entiteDialog;

    private LienDialog lienDialog;

    private IMCDObjet objet;

    private IMCDLien lien;

    public MCDPanel(OldMCDComponent mcdComponent, OldMLDComponent mldComponent,
            SQLCommand sqlCommand)
    {
        super("MCD");
        
        this.mcdComponent = mcdComponent;
        this.mldComponent = mldComponent;
        this.sqlCommand = sqlCommand;
        this.actionHandler = new ActionHandler();

        initAction();
        initToolbar();
        initPopup();
        initDialog();

        chooser = new JFileChooser();
        chooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
        chooser.setFileHidingEnabled(true);

        AnalyseFilter af;
        FileChooserFilter cf;
        chooser.resetChoosableFileFilters();
        cf = new FileChooserFilter("PNG");
        cf.setExtension("png");
        cf.setDescription("Image PNG");
        chooser.addChoosableFileFilter(cf);
        chooser.setDialogType(JFileChooser.SAVE_DIALOG);

        this.setBorder(BorderFactory.createEmptyBorder(3, 3, 0, 3));

        this.setLayout(new BorderLayout());
        this.add(BorderLayout.CENTER, new JScrollPane(mcdComponent));
        this.add(BorderLayout.NORTH, toolbar);
        
        mcdComponent.addMouseListener(new MouseHandler());
    }

    private void initToolbar()
    {
        toolbar = new JPanel();
        toolbar.setLayout(new FlowLayout(FlowLayout.LEFT));

        toolbar.add(new JButton(addEntite) {

            {
                setText("");
                addMouseListener(Application.statusbar.getHandler());
            }
        });

        toolbar.add(new JButton(addAssociation) {

            {
                setText("");
                addMouseListener(Application.statusbar.getHandler());
            }
        });

        toolbar.add(btnLien = new JToggleButton(addLien) {

            {
                setText("");
                addMouseListener(Application.statusbar.getHandler());
            }
        });

        toolbar.add(new JToolBar.Separator());

        toolbar.add(new JButton(saveGraphic) {

            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });
    }

    private void initPopup()
    {
        popupLien = new JPopupMenu();

        popupLien.add(new JMenuItem(modLien) {

            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });

        popupLien.addSeparator();

        popupLien.add(new JMenuItem(delLien) {

            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });

        popupEntite = new JPopupMenu();

        popupEntite.add(new JMenuItem(modEntite) {

            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });

        popupEntite.addSeparator();

        popupEntite.add(new JMenuItem(delObjet) {

            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });

        popupAssociation = new JPopupMenu();

        popupAssociation.add(new JMenuItem(modAssociation) {

            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });

        popupAssociation.addSeparator();

        popupAssociation.add(new JMenuItem(delObjet) {

            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });

        popupSaveGraphic = new JPopupMenu();
        popupSaveGraphic.add(new JMenuItem(saveGraphic) {
            {
                addMouseListener(Application.statusbar.getHandler());
            }
        });
    }

    private void initAction()
    {        
        addEntite = new BasicAction("Entit�", "Ajouter une entit�", "ADD_ENT",
                ImageLoader.getInstance().getIcon("Entite.png"), 0, null);
        addEntite.addActionListener(actionHandler);

        addAssociation = new BasicAction("Association",
                "Ajouter une association", "ADD_ASS", ImageLoader.getInstance().getIcon("Association.png"), 0, null);
        addAssociation.addActionListener(actionHandler);

        addLien = new BasicAction("Lien", "Ajouter un lien", "ADD_LIEN",
                ImageLoader.getInstance().getIcon("Lien.png"), 0, null);
        addLien.addActionListener(actionHandler);

        delLien = new BasicAction("Supprimer", "Supprimer le lien", "DEL_LIEN",
                ImageLoader.getInstance().getIcon("Delete.png"), 0, null);
        delLien.addActionListener(actionHandler);

        delObjet = new BasicAction("Supprimer", "Supprimer l'objet",
                "DEL_OBJET", ImageLoader.getInstance().getIcon("Delete.png"), 0, null);
        delObjet.addActionListener(actionHandler);

        modEntite = new BasicAction("Modifier", "Modifier l'entit�",
                "MOD_OBJET", ImageLoader.getInstance().getIcon("Edit.png"), 0, null);
        modEntite.addActionListener(actionHandler);

        modAssociation = new BasicAction("Modifier", "Modifier l'association",
                "MOD_OBJET", ImageLoader.getInstance().getIcon("Edit.png"), 0, null);
        modAssociation.addActionListener(actionHandler);

        modLien = new BasicAction("Modifier", "Modifier le lien", "MOD_LIEN",
                ImageLoader.getInstance().getIcon("Edit.png"), 0, null);
        modLien.addActionListener(actionHandler);

        verif = new BasicAction("V�rification", "V�rification du MCD",
                "VERIF_MCD", ImageLoader.getInstance().getIcon("OK.png"), 0, null);
        verif.addActionListener(actionHandler);

        buildMLD = new BasicAction("Construction",
                "Construction du MLD et du script SQL", "BUILD_MLD",
                ImageLoader.getInstance().getIcon("Build.png"), 0, KeyStroke
                        .getKeyStroke(KeyEvent.VK_F5, 0));
        buildMLD.addActionListener(actionHandler);

        saveGraphic = new BasicAction("Sauvegarder le graphique",
                "Sauvegarder le graphique dans un fichier PNG", "SAVE_GRAPH",
                ImageLoader.getInstance().getIcon("Save.png"), 0, null);
        saveGraphic.addActionListener(actionHandler);
    }

    private String chooseFile()
    {
        if (chooser.showDialog(org.eucalyptus.analysesi.Application.analyseFrame, null) == JFileChooser.APPROVE_OPTION) {
            return chooser.getSelectedFile().getAbsolutePath();
        }

        return null;
    }

    public BasicAction getVerif()
    {
        return verif;
    }

    public BasicAction getBuildLMD()
    {
        return buildMLD;
    }

    private void initDialog()
    {
        entiteDialog = new EntiteDialog(mcdComponent.getData());
        lienDialog = new LienDialog();
    }

    private class ActionHandler implements ActionListener
    {
        public void actionPerformed(ActionEvent e)
        {
            String action = e.getActionCommand();

            if (action.equals("ADD_ENT")) {
                DictionnaireTable data = mcdComponent.getData();
                data.addObserver(mcdComponent.addEntite());
            } else if (action.equals("ADD_ASS")) {
                DictionnaireTable data = mcdComponent.getData();
                data.addObserver(mcdComponent.addAssociation());
            } else if (action.equals("ADD_LIEN")) {
                if (btnLien.getSelectedObjects() != null)
                    mcdComponent.addLien();
                else
                    ((Graph)mcdComponent).annulerCreerLien();
            } else if (action.equals("DEL_LIEN")) {
                String mess = "Voulez-vous vraiment supprimer le lien s�lectionn� ?";
                if (JOptionPane.showConfirmDialog(null, mess, "Analyse",
                        JOptionPane.YES_NO_OPTION) != JOptionPane.YES_OPTION)
                    return;
                mcdComponent.removeLien();
            } else if (action.equals("DEL_OBJET")) {
                DictionnaireTable data = mcdComponent.getData();
                String mess = "Voulez-vous vraiment supprimer l'objet s�lectionn� ?";
                if (JOptionPane.showConfirmDialog(null, mess, "Analyse",
                        JOptionPane.YES_NO_OPTION) != JOptionPane.YES_OPTION)
                    return;
                data.deleteObserver(mcdComponent.removeObjet());
            } else if (action.equals("MOD_OBJET")) {
                entiteDialog.load((OldMCDObjet) objet);
            } else if (action.equals("MOD_LIEN")) {
                lienDialog.load((OldMCDLien) lien);
            } else if (action.equals("VERIF_MCD")) {
                mcdComponent.isCorrect(OldMCDComponent.SHOW_ALL);
            } else if (action.equals("BUILD_MLD")) {
                if (mcdComponent.buildMLD(mldComponent,
                        OldMCDComponent.HIDE_ALL)) {
                    mldComponent.buildSQL(mcdComponent.getData(), sqlCommand);
                }
                mcdComponent.buildMLD(mldComponent,
                        OldMCDComponent.CREATE_MCD);
            } else if (action.equals("SAVE_GRAPH")) {
                String fileName = chooseFile();
                if (fileName == null)
                    return;

                if (!Utilities.getExtension(fileName).equals("png")
                        && !Utilities.getExtension(fileName).equals("PNG"))
                    fileName = fileName + ".png";

                //((Graph)mcdComponent).enleverFocus();

                try {
                    File imageFile;
                    FileImageOutputStream outputStream;
                    BufferedImage img;
                    Graphics g;
                    Graphics2D g2d;
                    Rectangle2D r;

                    imageFile = new File(fileName);
                    img = new BufferedImage(
                            (int) (((Graph)mcdComponent).getPreferredSize().getWidth()),
                            (int) (((Graph)mcdComponent).getPreferredSize().getHeight()),
                            BufferedImage.TYPE_INT_RGB);

                    g = img.getGraphics();
                    g2d = (Graphics2D) g;

                    g2d.setColor(new Color(255, 255, 255));
                    r = new Rectangle2D.Double(0, 0, img.getWidth(), img
                            .getHeight());
                    g2d.fill(r);

                    ((Graph)mcdComponent).paintComponent(g2d);

                    PNGImageWriter writer = new PNGImageWriter(null);

                    writer.setOutput(outputStream = new FileImageOutputStream(
                            imageFile));
                    writer.write(img);

                    outputStream.close();

                    writer.dispose();

                } catch (IOException err) {
                    GUIUtilities.error("Impossible de sauvegarder le fichier "
                            + fileName);
                }
            }
        }
    }

    private class MouseHandler extends MouseAdapter
    {
        public void mouseReleased(MouseEvent e)
        {
            objet = null;
            lien = null;
            //if (e.isPopupTrigger()) Ne marche pas avec le JDK d'IBM
            if (e.getButton() == MouseEvent.BUTTON3) {
                Object o = ((Graph)mcdComponent).getObjectFromLocation(e.getX(), e
                        .getY());
                if (o instanceof IMCDLien) {
                    popupLien.show(e.getComponent(), e.getX(), e.getY());
                    lien = (IMCDLien) o;
                } else if (o instanceof IMCDAssociation) {
                    popupAssociation.show(e.getComponent(), e.getX(), e.getY());
                    objet = (IMCDObjet) o;
                } else if (o instanceof IMCDEntite) {
                    popupEntite.show(e.getComponent(), e.getX(), e.getY());
                    objet = (IMCDObjet) o;
                } else {
                    popupSaveGraphic.show(e.getComponent(), e.getX(), e.getY());
                }
            }
            if (btnLien.getSelectedObjects() != null)
                btnLien.doClick();
        }

        public void mouseClicked(MouseEvent e)
        {
            if (e.getButton() == MouseEvent.BUTTON1 && e.getClickCount() == 2) {
                Object o = ((Graph)mcdComponent).getObjectFromLocation(e.getX(), e
                        .getY());
                if (o instanceof IMCDLien) {
                    lienDialog.load((IMCDLien) o);
                } else if (o instanceof IMCDAssociation) {
                    entiteDialog.load((IMCDAssociation) o);
                } else if (o instanceof OldMCDEntite) {
                    entiteDialog.load((IMCDObjet) o);
                }
            }
        }
    }
}*/