/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.plugin;

import java.awt.BasicStroke;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Stroke;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;

import javax.swing.Action;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.eucalyptus.analysesi.plugin.Plugin;
import org.eucalyptus.egt.EgtUtilities;
import org.eucalyptus.egt.factory.ActionFactory;
import org.eucalyptus.egt.loader.ImageLoader;

/**
 * Ce composant graphique affiche/install/désinstalle les plugins.
 * 
 * @author Loic Dreux
 */
public class PluginComponent extends JComponent {
	/**
	 * Le plugin.
	 */
	private Plugin plugin;

	/**
	 * Suppression d'un plugin.
	 */
	private Action delete;

	/**
	 * La liste des listeners
	 */
	private List<PluginListener> pluginListeners;

	/**
	 * Le constructeur du {@link PluginComponent}.
	 * 
	 * @param pluginManager
	 *            le gestionnaire de plugins
	 * @param plugin
	 *            le plugin
	 */
	public PluginComponent(final Plugin plugin) {
		super();
		this.setLayout(new BorderLayout());

		// Affectation/Instance
		this.plugin = plugin;
		this.pluginListeners = new ArrayList<PluginListener>();
		this.delete = ActionFactory.buildAction("", "Supprimer le plugin",
				"DELETE_PLUGIN", ImageLoader.getInstance()
						.getIcon("Delete.png"), 0, null, new DeleteHandler());

		// Création du composant
		this.setBackground(Color.WHITE);
		this.add(BorderLayout.CENTER, new JPanel(new BorderLayout()) {
			{
				this.setBackground(PluginComponent.this.getBackground());

				// On ajoute le titre
				JLabel title = new JLabel(plugin.getName());
				title.setFont(title.getFont().deriveFont(Font.BOLD));
				title.setBorder(BorderFactory.createEmptyBorder(6, 6, 6, 6));
				this.add(BorderLayout.NORTH, title);

				// On ajoute la description
				JLabel description = new JLabel(EgtUtilities
						.getCuttedSwingLabel(plugin.getDescription(), 50));
				description.setBorder(BorderFactory.createEmptyBorder(0, 15, 6,
						6));
				this.add(BorderLayout.SOUTH, description);
			}
		});
		this.add(BorderLayout.EAST, new JPanel(new FlowLayout()) {
			{
				// On ajoute le bouton supprimer
				this.setBackground(PluginComponent.this.getBackground());
				this.add(new JButton(delete));
			}
		});
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.JComponent#paintComponent(java.awt.Graphics)
	 */
	@Override
	public void paintComponent(Graphics g) {
		super.paintComponent(g);

		Graphics2D g2d = (Graphics2D) g;
		int h = this.getSize().height;
		int w = this.getSize().width;

		g2d.setColor(this.getBackground());
		g2d.fillRect(0, 0, w, h);

		Stroke stroke = new BasicStroke(1.0f, BasicStroke.CAP_BUTT,
				BasicStroke.JOIN_MITER, 1.0f, new float[] { 5.0f, 5.0f }, 1.0f);
		g2d.setStroke(stroke);
	}
	
	/**
	 * Ajoute à {@link PluginListener} au composant.
	 * @param listener le listener à ajouter
	 */
	public void addPluginListener(PluginListener listener) {
		pluginListeners.add(listener);
	}
	
	/**
	 * Supprimer un {@link PluginListener} au composant.
	 * @param listener le listener à supprimer
	 */
	public void removePluginListener(PluginListener listener) {
		pluginListeners.remove(listener);
	}

	/**
	 * @return
	 */
	@Override
	public Dimension getMaximumSize() {
		return new Dimension((int) super.getMaximumSize().getWidth(),
				(int) this.getPreferredSize().getHeight());
	}

	/**
	 * Le Handler qui s'occuper de la suppression
	 * 
	 * @author Loic Dreux
	 */
	private class DeleteHandler implements ActionListener {

		/* (non-Javadoc)
		 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
		 */
		@Override
		public void actionPerformed(ActionEvent e) {
			PluginEvent event = new PluginEvent(PluginComponent.this, plugin);
			
			// On informe tous les listeners
			for(PluginListener listener: pluginListeners) {
				listener.pluginDeleted(event);
			}
		}
	}
}
