/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.plugin;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.Action;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import org.eucalyptus.analysesi.gui.AnalyseSIDialog;
import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.eucalyptus.analysesi.gui.Messages;
import org.eucalyptus.analysesi.plugin.Plugin;
import org.eucalyptus.analysesi.plugin.PluginManager;
import org.eucalyptus.egt.EgtUtilities;
import org.eucalyptus.egt.factory.ActionFactory;
import org.eucalyptus.egt.loader.ImageLoader;

/**
 * La boite de dialogue qui permet la gestion des plugins.
 * 
 * @author Loic Dreux
 */
public class PluginsDialog extends AnalyseSIDialog {
	
	/**
	 * Le gestionnaire de plugin
	 */
	private PluginManager pluginManager;

	/**
	 * Le Handle qui gère les évènements.
	 */
	private ActionHandler actionHandler;
	
	/**
	 * Le Handle qui gère les plugins.
	 */
	private PluginHandler pluginHandler;

	/**
	 * L'action fermer.
	 */
	private Action close;
	
	/**
	 * Le panel qui contient la liste des plugins.
	 */
	private JPanel pluginsPanel;

	/**
	 * Le constructeur PluginsDialog.
	 * 
	 * @param analyseSIFrame
	 *            La fenêtre principale AnalyseSI.
	 */
	public PluginsDialog(AnalyseSIFrame analyseSIFrame) {
		super(
				analyseSIFrame,
				Messages.getString("PluginsDialog.title"), Messages.getString("PluginsDialog.description"), ImageLoader.getInstance().getIcon("exec.png")); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$

		// AffectationPluginHandler
		this.pluginManager = analyseSIFrame.getApplication().getPluginManager();

		// Initialisation des actions
		initActions();

		// Ajout des composants
		this.add(buildPanel());
		this.addBottomButton(new JButton(close));

		// Finitions
		this.setSize(500, 400);
		// this.pack();
		this.setResizable(false);
		EgtUtilities.centerComponent(this);
	}

	/**
	 * Initialise les actions.
	 */
	private void initActions() {
		actionHandler = new ActionHandler();
		pluginHandler = new PluginHandler();

		close = ActionFactory
				.buildAction(
						Messages.getString("PluginsDialog.close"), Messages.getString("PluginsDialog.closeLong"), Actions.CLOSE.name(), actionHandler); //$NON-NLS-1$ //$NON-NLS-2$
	}

	/**
	 * Construit le panel central.
	 * 
	 * @return la panel central
	 */
	private JPanel buildPanel() {
		JPanel p = new JPanel();
		p.setLayout(new BorderLayout());
		p.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));

		/*
		 * JList list = new JList(); list.setModel(new
		 * PluginsListModel(this.pluginManager)); p.add(new JScrollPane(list),
		 * BorderLayout.CENTER);
		 */
		pluginsPanel = new JPanel();
		pluginsPanel.setLayout(new BoxLayout(pluginsPanel, BoxLayout.Y_AXIS));
		updateListPlugins();
		p.add(new JScrollPane(pluginsPanel), BorderLayout.CENTER);

		return p;
	}
	
	/**
	 * Met à jour la liste des plugsin
	 */
	public void updateListPlugins() {
		pluginsPanel.removeAll();
		for (Plugin plugin : pluginManager.getInstalledPlugins()) {
			PluginComponent component = new PluginComponent(plugin);
			component.addPluginListener(pluginHandler);
			pluginsPanel.add(component);
		}
		for (Plugin plugin : pluginManager.getAvailablePlugins()) {
			PluginComponent component = new PluginComponent(plugin);
			component.addPluginListener(pluginHandler);
			pluginsPanel.add(component);
		}
		pluginsPanel.revalidate();
		pluginsPanel.repaint();
	}

	/**
	 * Le Handle qui gère les évènements.
	 * 
	 * @author Loic Dreux
	 */
	private class ActionHandler implements ActionListener {
		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent
		 * )
		 */
		@Override
		public void actionPerformed(ActionEvent e) {
			// Fermer
			if (e.getActionCommand().equals(Actions.CLOSE.name())) {
				PluginsDialog.this.setVisible(false);
			}
		}
	}

	/**
	 * Le handler qui gère les plugins.
	 * 
	 * @author Loic Dreux
	 */
	private class PluginHandler implements PluginListener {

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * org.eucalyptus.analysesi.gui.plugin.PluginListener#pluginDeleted(
		 * org.eucalyptus.analysesi.gui.plugin.PluginEvent)
		 */
		@Override
		public void pluginDeleted(PluginEvent e) {
			if (JOptionPane.showConfirmDialog(PluginsDialog.this
					.getAnalyseSIFrame(), "Etes-vous sur de vouloir supprimer le plugin ?", getAnalyseSIFrame().getName(),
					JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION) {
				pluginManager.removePlugin(e.getPlugin());
				updateListPlugins();
			}
		}
	}

	/**
	 * La liste des actions locales
	 * 
	 * @author Loic Dreux
	 */
	private enum Actions {
		/**
		 * Fermer.
		 */
		CLOSE,

	}
}
