/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.gui.reverse;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.Action;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JPasswordField;
import javax.swing.JTextField;

import org.eucalyptus.analysesi.db.DbConnectionParameters;
import org.eucalyptus.analysesi.db.DbManager;
import org.eucalyptus.analysesi.gui.AnalyseSIDialog;
import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.eucalyptus.analysesi.gui.Messages;
import org.eucalyptus.analysesi.gui.db.ConfiguredConnectionsList;
import org.eucalyptus.analysesi.gui.db.ConnectionEditor;
import org.eucalyptus.analysesi.gui.db.ConnectionsEvent;
import org.eucalyptus.analysesi.gui.db.ConnectionsListener;
import org.eucalyptus.analysesi.gui.renderer.DriverCellRenderer;
import org.eucalyptus.analysesi.gui.renderer.EngineCellRenderer;
import org.eucalyptus.analysesi.reverse.ReverseManager;
import org.eucalyptus.egt.EgtUtilities;
import org.eucalyptus.egt.factory.ActionFactory;
import org.eucalyptus.egt.factory.EgtBorderFactory;
import org.eucalyptus.egt.loader.ImageLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;

/**
 * La boite de dialog qui permet la création d'un modèle à partir d'une base de
 * données existante.
 * 
 * @author Loic Dreux
 */
public class ReverseDialog extends AnalyseSIDialog implements ConnectionEditor {
	private Logger logger = LoggerFactory.getLogger(ReverseDialog.class);
	
	/*
	 * ============================================= Les Managers
	 */

	/**
	 * Le gestionnaire de base de données.
	 */
	private DbManager dbManager;

	/**
	 * Le gestionnaire de moteur
	 */
	private ReverseManager reverseManager;

	/*
	 * ============================================= Les Actions
	 */

	/**
	 * Le Handle qui gère les évènements.
	 */
	private ActionHandler handler;

	/**
	 * L'action confirmer.
	 */
	private Action ok;

	/**
	 * L'action tester la connection.
	 */
	private Action testConnection;

	/**
	 * L'action annumer.
	 */
	private Action cancel;

	/*
	 * ============================================= Les Composants
	 */

	private ConfiguredConnectionsList connectionsList;

	/**
	 * La combobox qui contient les drivers.
	 */
	private JComboBox driverComboBox;

	/**
	 * la combobox qui cont // Avant d'ouvrir la fenêtre on vérifie qu'il existe
	 * ient les moteurs.
	 */
	private JComboBox engineComboBox;

	/**
	 * La textfield qui contient le mot de passe.
	 */
	private JTextField passwordTextField;

	/**
	 * La textfield qui contient l'url.
	 */
	private JTextField urlTextField;

	/**
	 * La textfield qui contient le user.
	 */
	private JTextField userTextField;

	/**
	 * Le constructeur de la boite de dialog de création d'un modèle à partir
	 * d'une base de données
	 * 
	 * @param analyseSIFrame
	 *            la fenêtre principale d'AnalyseSI
	 */
	public ReverseDialog(AnalyseSIFrame analyseSIFrame) {
		super(
				analyseSIFrame,
				Messages.getString("ReverseDialog.title"), Messages.getString("ReverseDialog.description"), ImageLoader.getInstance().getIcon("exec.png")); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$

		// Affectation
		this.dbManager = analyseSIFrame.getApplication().getDbManager();
		this.reverseManager = analyseSIFrame.getApplication().getReverseManager();

		// Initialisation des actions
		initActions();

		// Ajout des composants
		this.add(buildPanel());
		this.addBottomButton(new JButton(testConnection), new JButton(ok),
				new JButton(cancel));

		// Finitions
		// this.setSize(500, 400);
		this.pack();
		this.setResizable(false);
		EgtUtilities.centerComponent(this);
	}

	/**
	 * Construit le panel central.
	 * 
	 * @return la panel central
	 */
	private JPanel buildPanel() {
		JPanel p;

		// Initialisation de la liste des connections paramétrées
		connectionsList = new ConfiguredConnectionsList(dbManager, this);
		connectionsList.addConnectionsListener(new ConnectionsHandler());

		// Initialisation des textfield pour la connection jdbc
		urlTextField = new JTextField();
		userTextField = new JTextField();
		passwordTextField = new JPasswordField();

		// Initialisation du combobox des moteurs
		engineComboBox = new JComboBox(new DefaultComboBoxModel(
				this.reverseManager.getReverseEngines().toArray()));
		engineComboBox.setRenderer(new EngineCellRenderer(engineComboBox
				.getRenderer()));

		// Initialisation du combobox des drivers
		driverComboBox = new JComboBox(new DefaultComboBoxModel(this.dbManager
				.getJdbcDrivers().toArray()));
		driverComboBox.addItemListener(new DriverHandler());
		driverComboBox.setRenderer(new DriverCellRenderer(driverComboBox
				.getRenderer()));
		if (driverComboBox.getItemCount() > 0) {
			urlTextField.setText(dbManager
					.getUrlStart((Class<?>) driverComboBox.getSelectedItem()));
		}

		// Inialisation du formulaire
		FormLayout layout = new FormLayout(
				"right:max(40mm;p), 4mm, 60mm", "p, 2mm, p, 2mm, p, 2mm, p, 2mm, p"); //$NON-NLS-1$ //$NON-NLS-2$
		PanelBuilder builder = new PanelBuilder(layout);
		builder.setDefaultDialogBorder();
		CellConstraints cc = new CellConstraints();

		builder.addLabel(
				Messages.getString("ReverseDialog.engine"), cc.xy(1, 1)); //$NON-NLS-1$
		builder.add(driverComboBox, cc.xy(3, 1));
		builder.addLabel(
				Messages.getString("ReverseDialog.driver"), cc.xy(1, 3)); //$NON-NLS-1$
		builder.add(engineComboBox, cc.xy(3, 3));
		builder.addLabel(Messages.getString("ReverseDialog.url"), cc.xy(1, 5)); //$NON-NLS-1$
		builder.add(urlTextField, cc.xy(3, 5));
		builder
				.addLabel(
						Messages.getString("ReverseDialog.login"), cc.xy(1, 7)); //$NON-NLS-1$
		builder.add(userTextField, cc.xy(3, 7));
		builder.addLabel(
				Messages.getString("ReverseDialog.password"), cc.xy(1, 9)); //$NON-NLS-1$
		builder.add(passwordTextField, cc.xy(3, 9));

		// On retourne le panel
		p = builder.getPanel();
		p.setBorder(EgtBorderFactory.createEtchedBorder());

		JPanel pane2 = new JPanel(new BorderLayout());
		pane2.add(BorderLayout.WEST, connectionsList);
		pane2.add(BorderLayout.CENTER, p);

		return pane2;
	}

	/**
	 * Initialise les actions.
	 */
	private void initActions() {
		handler = new ActionHandler();

		ok = ActionFactory
				.buildAction(
						Messages.getString("ReverseDialog.run"), Messages.getString("ReverseDialog.runLong"), Actions.OK.name(), handler); //$NON-NLS-1$ //$NON-NLS-2$
		cancel = ActionFactory
				.buildAction(
						Messages.getString("ReverseDialog.cancel"), Messages.getString("ReverseDialog.cancelLong"), Actions.CANCEL.name(), handler); //$NON-NLS-1$ //$NON-NLS-2$
		testConnection = ActionFactory
				.buildAction(
						Messages.getString("ReverseDialog.testConnection"), //$NON-NLS-1$
						Messages.getString("ReverseDialog.testConnectionLong"), Actions.TEST_CONNECTION.name(), //$NON-NLS-1$
						handler);
	}

	/**
	 * Retourne un objet {@link DbConnectionParameters}.
	 * 
	 * @return un objet {@link DbConnectionParameters}
	 */
	public DbConnectionParameters getDbConnectionParameters() {
		return new DbConnectionParameters(urlTextField.getText(), userTextField
				.getText(), passwordTextField.getText(),
				((Class<?>) driverComboBox.getSelectedItem()).getName());
	}

	/**
	 * Le Handle qui gère les évènements.
	 * 
	 * @author Loic Dreux
	 */
	private class ActionHandler implements ActionListener {
		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent
		 * )
		 */
		@Override
		public void actionPerformed(ActionEvent e) {
			// OK
			if (e.getActionCommand().equals(Actions.OK.name())) {
				ReverseDialog.this.setVisible(false);
			}
			// Cancel
			else if (e.getActionCommand().equals(Actions.CANCEL.name())) {
				ReverseDialog.this.setVisible(false);
			}
			// Tester la connection
			else if (e.getActionCommand()
					.equals(Actions.TEST_CONNECTION.name())) {
				// Si la connection est correct
				if (dbManager.testConnection(getDbConnectionParameters())) {
					JOptionPane.showMessageDialog(ReverseDialog.this
							.getAnalyseSIFrame(),
							Messages.getString("ReverseDialog.connectionOK"), //$NON-NLS-1$
							getAnalyseSIFrame().getName(),
							JOptionPane.INFORMATION_MESSAGE);
				}
				// Si la connection n'est pas correct
				else {
					JOptionPane
							.showMessageDialog(
									ReverseDialog.this.getAnalyseSIFrame(),
									Messages
											.getString("ReverseDialog.connectionFailed"), //$NON-NLS-1$
									getAnalyseSIFrame().getName(),
									JOptionPane.ERROR_MESSAGE);
				}
			}
		}
	}

	/**
	 * La liste des actions locales
	 * 
	 * @author Loic Dreux
	 */
	private enum Actions {
		/**
		 * Annuler.
		 */
		CANCEL,
		/**
		 * Confirmer.
		 */
		OK,
		/**
		 * Tester la connection
		 */
		TEST_CONNECTION
	}

	/**
	 * Changement de Driver.
	 * 
	 * @author Loic Dreux
	 */
	private class DriverHandler implements ItemListener {
		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * java.awt.event.ItemListener#itemStateChanged(java.awt.event.ItemEvent
		 * )
		 */
		@Override
		public void itemStateChanged(ItemEvent e) {
			urlTextField.setText(ReverseDialog.this.dbManager
					.getUrlStart((Class<?>) driverComboBox.getSelectedItem()));
			userTextField.setText("");
			passwordTextField.setText("");
		}
	}

	/**
	 * Le gestionnaire de connections
	 * 
	 * @author Loic Dreux
	 */
	private class ConnectionsHandler implements ConnectionsListener {

		/*
		 * (non-Javadoc)
		 * 
		 * @seeorg.eucalyptus.analysesi.gui.db.ConnectionsListener#
		 * configuredConnectionsSaved
		 * (org.eucalyptus.analysesi.gui.db.ConnectionsEvent)
		 */
		@Override
		public void configuredConnectionsSaved(ConnectionsEvent e) {
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * org.eucalyptus.analysesi.gui.db.ConnectionsListener#connectionSelected
		 * (org.eucalyptus.analysesi.gui.db.ConnectionsEvent)
		 */
		@Override
		public void connectionSelected(ConnectionsEvent e) {
			logger.debug("Connection sélectionnée");
			driverComboBox.setSelectedItem(dbManager.getJdbcDriver(e.getSelectedConnection()));
			urlTextField.setText(e.getSelectedConnection().getUrl());
			userTextField.setText(e.getSelectedConnection().getUser());
			passwordTextField.setText(e.getSelectedConnection().getPassword());
		}
	}
}
