/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
/**
 * 
 */
package org.eucalyptus.analysesi.gui.save;

import java.io.File;

import javax.swing.filechooser.FileFilter;

import org.eucalyptus.analysesi.save.Format;

/**
 *
 * @author Loic Dreux
 */
public class HibiscusFileFilter extends FileFilter {

	/**
	 * Le format
	 */
	private Format format;
	
	/**
	 * Le constructeur de {@link HibiscusFileFilter}.
	 * @param format Le format de fichier
	 */
	public HibiscusFileFilter(Format format) {
		this.format = format;
	}
	
	/* (non-Javadoc)
	 * @see javax.swing.filechooser.FileFilter#accept(java.io.File)
	 */
	@Override
	public boolean accept(File f) {
		if (f == null)
            return false;

        if (f.isDirectory())
            return true;
        
        String extension = getExtension(f);
        if (extension == null)
        	return false;

        return getExtension(f).equals(format.getFileExtension());
	}

	/* (non-Javadoc)
	 * @see javax.swing.filechooser.FileFilter#getDescription()
	 */
	@Override
	public String getDescription() {
		return format.getDescription() + " (*." + format.getFileExtension() + ")";
	}

	/**
	 * Retourne l'extension d'un fichier.
	 * @param f Le fichier
	 * @return l'extension du fichier
	 */
	private String getExtension(File f)
    {
        if (f == null)
            return null;

        String filename = f.getName();
        int i = filename.lastIndexOf('.');

        return (i > 0 && i < filename.length() - 1) ? filename.substring(i + 1)
                .toLowerCase() : null;
    }
	
	/**
	 * Retourne le {@link Format}.
	 * @return le format
	 */
	public Format getFormat() {
		return this.format;
	}
}
