/*
 * Copyright BluePackage, 2007
 * 
 * dreuxl@gmail.com
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.model;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * Un type de base de données abstrait.
 *
 * @author Loic Dreux
 */
@XStreamAlias("database")
public abstract class AbstractDatabase implements Database {

	/**
	 * Le nom du type de base de données.
	 */
	@XStreamAlias("name")
	private String name;
	
	/**
	 * La description du type de base de données.
	 */
	@XStreamAlias("description")
	private String description;
	
	/**
	 * Le constructeur de la classe AbstractDatabase}
	 * @param name le nom du type de base de données
	 */
	public AbstractDatabase(String name) {
		this(name, "");
	}
	
	/**
	 * Le constructeur de la classe {@link AbstractDatabase}.
	 * @param name le nom du type de base de données
	 * @param description la description du type de base de données
	 */
	public AbstractDatabase(String name, String description) {
		this.name = name;
		this.description = description;
	}
	
	/* (non-Javadoc)
	 * @see org.analysesi.merise.model.Database#getDescription()
	 */
	public String getDescription() {
		return this.description;
	}

	/* (non-Javadoc)
	 * @see org.analysesi.merise.model.Database#getName()
	 */
	public String getName() {
		return this.name;
	}
}
