/*
 * Copyright AnalyseSI, 2007
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.model;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * Cette classe représente un attribut a associer à une {@link Entity}.
 *
 * @author Yann D'ISANTO
 */
@XStreamAlias("attribute")
public class Attribute {
    
    /**
     * Le nom de l'attribut.
     */
	@XStreamAlias("name")
    private String name;
    
    /**
     * La description de l'attribut.
     */
	@XStreamAlias("description")
    private String description;
    
    /**
     * Le type de l'attribut.
     */
	@XStreamAlias("type")
    private TypeAttribute type;
    
    /**
     * Le constructeur par défaut de la classe {@link Attribute}.
     * Construit un attribut avec pour nom une chaine de caractéres vide. 
     */
    public Attribute() {
        this("");
    }
    
    /**
     * Construit un attribut avec un nom. 
     * @param name Le nom de la attribut
     */
    public Attribute(String name) {
        this(name, null);
    }
    
    /**
     * Construit un attribut avec un nom et un type.
     * @param name Le nom de l'attribut
     * @param type Le type de l'attribut
     */
    public Attribute(String name, TypeAttribute type) {
        this.name = name;
        this.type = type;
    }
    
    /**
     * Retourne le nom de l'attribut.
     * @return le nom de l'attribut
     */
    public String getName() {
        return name;
    }
    
    /**
     * Modifie le nom de l'attribut.
     * @param name le nouveau nom de l'attribut
     */
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * Retourne la description de l'attribut.
     * @return la description de l'attribut
     */
    public String getDescription() {
        return description;
    }
    
    /**
     * Retourne la nouvelle description de l'attribut.
     * @param description la nouvelle description de l'attribut
     */
    public void setDescription(String description) {
        this.description = description;
    }
    
    /**
     * Retourne le type de l'attribut.
     * @return le type de l'attribut
     */
    public TypeAttribute getType() {
        return type;
    }
    
    /**
     * Modifie le type de l'attribut.
     * @param type le nouveau type de l'attribut
     */
    public void setType(TypeAttribute type) {
        this.type = type;
    }
    
    /* (non-Javadoc)
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(Object o) {
        if(o == this) {
            return true;
        }
        if(o instanceof Attribute) {
            return name.equals(((Attribute) o).getName());
        }
        return false;
    }
    
    /* (non-Javadoc)
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        int hash = 5;
        final int multiplier = 13;
        hash = multiplier * hash + (name == null ? 0 : name.hashCode());
        return hash;
    }
    
    /* (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return this.name + " - " + this.description + " - " + this.type;
    }
}
