/*
 * Copyright AnalyseSI, 2007
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.model;

import java.util.ArrayList;
import java.util.List;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * Le dictionnaire des informations.
 *
 * @author Loic DREUX
 */
@XStreamAlias("dictionary")
public class Dictionary {
	
	/**
	 * La liste des attributs.
	 */
	@XStreamAlias("attributes")
	private List<Attribute> attributes;

	/**
	 * Le constructeur de la classe {@link Dictionary}.
	 */
	public Dictionary() {
		this.attributes = new ArrayList<Attribute>();
	}

	/**
	 * Ajoute un attribut au dictionnaire.
	 * @param attribute l'attribut à ajouter au dictionnaire
	 */
	public void add(Attribute attribute) {
		attributes.add(attribute);
	}

	/**
	 * Supprime un attribut au dictionnaire.
	 * @param attribute l'attribut à supprimer du dictionnaire
	 */
	public void remove(Attribute attribute) {
		attributes.remove(attribute);
	}
	
	/**
	 * Supprime tous les attributs du dictionnaires.
	 */
	public void clear()
	{
		attributes.clear();
	}

	/**
	 * Retourne un attribut du dictionnaire selon son index. 
	 * @param index l'index de l'attribut à retourner
	 * @return un attribut du dictionnaire selon son index
	 */
	public Attribute get(int index) {
		return attributes.get(index);
	}

	/**
	 * Retourne le nombre d'attribut présent dans le dictionnaire.
	 * @return le nombre d'attribut présent dans le dictionnaire
	 */
	public int size() {
		return attributes.size();
	}
	
	/**
	 * Echange l'attribut positionné à un index avec l'attribut précédant.
	 * N'a aucun effet sur le premier attribut du dictionnaire.
	 * @param index l'index de l'attribut à échanger
	 */
	public void up(int index) {
		if (index > 1)
		{
			Attribute information = attributes.get(index);
			attributes.remove(index);
			attributes.add(index - 1, information);
		}
	}
	
	/**
	 * Echange l'attribut positionné à un index avec l'attribut suivant.
	 * N'a aucun effet sur le dernier attribut du dictionnaire.
	 * @param index l'index de l'attribut à échanger
	 */
	public void down(int index) {
		if (index < attributes.size() - 2)
		{
			Attribute information = attributes.get(index);
			attributes.remove(index);
			attributes.add(index + 1, information);
		}
	}
}
