/*
 * Copyright AnalyseSI, 2007
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.model;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * Un lien merise.
 *
 * @author Yann D'ISANTO
 */
@XStreamAlias("meriseLink")
public class MeriseLink {
    
	/**
	 * La description du lien
	 */
	@XStreamAlias("description")
	private String description;
	
    /**
     * L'entité merise
     */
	@XStreamAlias("entity")
    private Entity entity;

	/**
     * La relation merise
     */
	@XStreamAlias("relation")
    private Relation relation;

	/**
	 * Les cardinalités du lien
	 */
	@XStreamAlias("multiplicity")
	private Multiplicity multiplicity;

	/**
	 * Le constructeur de {@link MeriseLink}.
	 */
	public MeriseLink() {
    }

	/**
	 * Retourne la description. 
	 * @return la description
	 */
	public String getDescription() {
		return description;
	}
	
    /**
     * Retourne l'entité merise.
     * @return l'entité merise
     */
    public Entity getEntity() {
        return entity;
    }
    
	/**
	 * Retourne les cardinalités.
	 * @return les cardinalités
	 */
	public Multiplicity getMultiplicity() {
		return multiplicity;
	}
    
    /**
     * Retourne la relation merise.
     * @return la relation merise
     */
    public Relation getRelation() {
        return relation;
    }

    /**
     * Modifie la description.
	 * @param description la description
	 */
	public void setDescription(String description) {
		this.description = description;
	}

    /**
     * Modifie l'entité merise.
     * @param entity l'entité merise
     */
    public void setEntity(Entity entity) {
        this.entity = entity;
    }

    /**
     * Modifie les cardinalités.
	 * @param multiplicity les cardinalités
	 */
	public void setMultiplicity(Multiplicity multiplicity) {
		this.multiplicity = multiplicity;
	}

    /**
     * Modifie la relation merise.
     * @param relation la relation merise
     */
    public void setRelation(Relation relation) {
        this.relation = relation;
    }
}
