/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.model;

import org.eucalyptus.analysesi.model.generic.GenericDatabase;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * Le modèle Merise.
 * 
 * @author Loic DREUX
 */
@XStreamAlias("meriseModel")
public class MeriseModel {

	/**
	 * Le dictionnaire des informations.
	 */
	@XStreamAlias("dictionary")
	private Dictionary dictionary;

	/**
	 * Le Modèle Conceptuel des données.
	 */
	@XStreamAlias("mcd")
	private MCD mcd;

	/**
	 * Le type de Base de données à utiliser. Par défaut le type de base de
	 * données générique {@link GenericDatabase}.
	 */
	@XStreamAlias("database")
	private Database database;

	/**
	 * Le constructeur par défaut de la classe {@link MeriseModel}.
	 */
	public MeriseModel() {
		this.dictionary = new Dictionary();
		this.mcd = new MCD(this.dictionary);
		this.database = GenericDatabase.getInstance();
	}

	/**
	 * Supprime les données du modèle de données merise.
	 */
	public void clear() {
		this.dictionary = new Dictionary();
		this.mcd = new MCD(this.dictionary);
	}

	/**
	 * Retourne le dictionnaire de données du modèle merise.
	 * 
	 * @return le dictionnaire de données du modèle merise
	 */
	public Dictionary getDictionary() {
		return this.dictionary;
	}

	/**
	 * Retourne le modèle conceptuel des données du modèle merise.
	 * 
	 * @return le modèle conceptuel des données du modèle merise
	 */
	public MCD getMcd() {
		return this.mcd;
	}

	/**
	 * Retourne le type de base de données associé au model.
	 * 
	 * @return le type de base de données associé au model
	 */
	public Database getDatabase() {
		return this.database;
	}
}
