/*
 * Copyright AnalyseSI, 2007
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.model;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.List;

import org.eucalyptus.analysesi.gui.AnalyseSIFrame;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Quelques méthodes utilitaires pour le model merise.
 *
 * @author Loic DREUX
 */
public class MeriseUtils {
	private static Logger logger = LoggerFactory.getLogger(AnalyseSIFrame.class);
	
	/**
	 * La liste des bases de données
	 */
	private static List<Database> databases;
	
	/**
	 * Retourne la liste des type de base de données.
	 * @return la liste des type de base de données
	 */
	public static List<Database> getDatabases() {
		if (databases != null)
			return databases;
		
		// On initialises la listes des bases de données
		databases = new ArrayList<Database>();
		
		// On parcours tous les packages commencant par org.anlysesi.merise.model
		Package[] packs = Package.getPackages();
		for (Package subpack: packs) {
			if(subpack.getName().startsWith("org.analysesi.merise.model")) {
				String subpackName = subpack.getName().substring(subpack.getName().lastIndexOf("."));
				subpackName = subpackName.toUpperCase().charAt(0) + subpackName.substring(1); 
				subpackName += "Database";
				try {
					Class<?> clazz = Class.forName(subpack.getName() + "." + subpackName);
					databases.add((Database)clazz.getMethod("getInstance").invoke(null));
				} catch (ClassNotFoundException e) {
					logger.warn("Le package '" + subpack.getName() + "' ne contient pas de classe " + subpackName);
				} catch (IllegalArgumentException e) {
					logger.error("Impossible d'appeler la méthode statique getInstance() sur l'objet", e);
				} catch (SecurityException e) {
					logger.error("Impossible d'appeler la méthode statique getInstance() sur l'objet", e);
				} catch (IllegalAccessException e) {
					logger.error("Impossible d'appeler la méthode statique getInstance() sur l'objet", e);
				} catch (InvocationTargetException e) {
					logger.error("Impossible d'appeler la méthode statique getInstance() sur l'objet", e);
				} catch (NoSuchMethodException e) {
					logger.error("Impossible d'appeler la méthode statique getInstance() sur l'objet", e);
				}
			}
		}
		
		return databases;
	}
}
