/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.model;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * Une note peut être associé à un objet merise ou à un lien afin d'afficher des
 * informations à l'utilisateur.
 * 
 * @author Yann D'ISANTO
 */
@XStreamAlias("note")
public class Note {

	/**
	 * Le titre de la note.
	 */
	@XStreamAlias("title")
	private String title;

	/**
	 * Le texte de la note.
	 */
	@XStreamAlias("text")
	private String text;

	/**
	 * Le lien qui associe la note à un objet merise ou un lien merise.
	 */
	@XStreamAlias("link")
	private NoteLink noteLink;

	/**
	 * Le constructeur de la classe {@link Note}.
	 * 
	 * @param title
	 *            le titre de la note
	 */
	public Note(String title) {
		this(title, "");
	}

	/**
	 * Le constructeur de la classe {@link Note}.
	 * 
	 * @param title
	 *            le titre de la note
	 * @param text
	 *            le texte de la note
	 */
	public Note(String title, String text) {
		this.title = title;
		this.text = text;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object o) {
		if (o == this) {
			return true;
		}
		if (o == null) {
			return false;
		}
		if (o instanceof Note) {
			return title.equals(((Note) o).getTitle());
		}
		return false;
	}

	/**
	 * Retourne le lien associé à la note.
	 * 
	 * @return le lien associé à la note
	 */
	public NoteLink getNoteLink() {
		return noteLink;
	}

	/**
	 * Retourne le texte de la note.
	 * 
	 * @return le texte de la note
	 */
	public String getText() {
		return text;
	}

	/**
	 * Retourne le titre de la note.
	 * 
	 * @return le titre de la note
	 */
	public String getTitle() {
		return title;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		int hash = 3;
		final int multiplier = 11;
		hash = multiplier * hash + (title == null ? 0 : title.hashCode());
		return hash;
	}

	/**
	 * Modifie la lien associé à la note.
	 * 
	 * @param noteLink
	 *            le lien associé à la note
	 */
	public void setNoteLink(NoteLink noteLink) {
		this.noteLink = noteLink;
	}

	/**
	 * Modifie le texte de la note.
	 * 
	 * @param text
	 *            le texte de la note
	 */
	public void setText(String text) {
		this.text = text;
	}

	/**
	 * Modifie le titre de la note.
	 * 
	 * @param title
	 *            le titre de la note
	 */
	public void setTitle(String title) {
		this.title = title;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return text;
	}
}
