/*
 * Copyright BluePackage, 2007
 * 
 * dreuxl@gmail.com
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.model.generic;

import org.eucalyptus.analysesi.model.AbstractTypeAttribute;
import org.eucalyptus.analysesi.model.TypeAttributeLabel;
import org.eucalyptus.analysesi.model.TypeAttributeProperty;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * Représente un type de données Nombre.
 *
 * @author Loic Dreux
 */
@XStreamAlias("generic_number")
@TypeAttributeLabel("Number")
public class NumberTypeAttribute extends AbstractTypeAttribute {

	/**
	 * La précision en nombre de chiffre entier.
	 */
	@TypeAttributeProperty("Precision")
	private int numericPrecision;
	
	/**
	 * La précision en nombre de chiffre après la virgule.
	 */
	@TypeAttributeProperty("Scale")
	private int numericScale;
	
	/**
	 * Le constructeur de la classe {@link NumberTypeAttribute}.
	 */
	public NumberTypeAttribute() {
		this(0, 0);
	}
	
	/**
	 * Le constructeur de la classe {@link NumberTypeAttribute}.
	 */
	public NumberTypeAttribute(int numericPrecision, int numericScale) {
		super("Number");
		
		this.numericPrecision = numericPrecision;
		this.numericScale = numericScale;
	}
	
	/**
	 * Retourne la précisison en nombre de chiffre après la virgule.
	 * @return la précisison en nombre de chiffre après la virgule
	 */
	public int getNumericPrecision() {
		return this.numericPrecision;
	}
	
	/**
	 * Retourne la précision en nombre de chiffre après la virgule.
	 * @return la précision en nombre de chiffre après la virgule
	 */
	public int getNumericScale() {
		return this.numericScale;
	}
	
	/* (non-Javadoc)
	 * @see org.analysesi.merise.model.TypeAttribute#formatToString()
	 */
	public String formatToString() {
		return this.getName() + " (" + this.numericPrecision + ", " + this.numericScale + ")";
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return this.formatToString();
	}
}
