/*
 * Copyright BluePackage, 2007
 * 
 * dreuxl@gmail.com
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.model.generic;

import org.eucalyptus.analysesi.model.AbstractTypeAttribute;
import org.eucalyptus.analysesi.model.TypeAttributeLabel;
import org.eucalyptus.analysesi.model.TypeAttributeProperty;

import com.thoughtworks.xstream.annotations.XStreamAlias;

/**
 * Représente un type de données Chaine de caractères.
 *
 * @author Loic Dreux
 */
@XStreamAlias("generic_varchar")
@TypeAttributeLabel("Varchar")
public class VarcharTypeAttribute extends AbstractTypeAttribute {

	/**
	 * La longueur de la chaine de caractères.
	 */
	@TypeAttributeProperty("Length")
	private int length;
	
	/**
	 * L'unité à appliquer à la longueur
	 */
	@TypeAttributeProperty("Unit")
	private Unit unit;
	
	/**
	 * Le constructeur de la classe {@link VarcharTypeAttribute}.
	 */
	public VarcharTypeAttribute() {
		this(255);
	}
	
	/**
	 * Le constructeur de la classe {@link VarcharTypeAttribute}.
	 * @param length la taille de la chaine de caractères
	 */
	public VarcharTypeAttribute(int length) {
		super("Varchar");
		
		this.length = length;
	}

	/**
	 * Retourne la longueur de la chaine de caractères.
	 * @return la longueur de la chaine de caractères
	 */
	public int getLength() {
		return length;
	}
	
	/**
	 * Retourne l'unité à appliquer à la longueur.
	 * @return l'unité à appliquer à la longueur
	 */
	public Unit getUnit() {
		return unit;
	}
	
	/* (non-Javadoc)
	 * @see org.analysesi.merise.model.TypeAttribute#formatToString()
	 */
	public String formatToString() {
		return this.getName() + " (" + this.length + " " + this.unit + ")";
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return this.formatToString();
	}
	
	/**
	 * Les différentes unités de mesure à appliquer à la longueur.
	 *
	 * @author Loic Dreux
	 */
	public enum Unit {
		BYTE, CHAR
	}
}
