/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.plugin;

import java.io.File;

import org.eucalyptus.analysesi.db.DbManager;
import org.eucalyptus.egt.JarFileLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Un plugin qui contient un driver pour les bases de données.
 * 
 * @author Loic Dreux
 */
public class DatabaseDriverPlugin extends Plugin {
	// Le logger
	@SuppressWarnings("unused")//$NON-NLS-1$
	private static final Logger logger = LoggerFactory
			.getLogger(DatabaseDriverPlugin.class);

	/**
	 * Le nom de la classe Driver.
	 */
	private String driverClass;

	/**
	 * Le début de l'url associé au driver JDBC.
	 */
	private String urlStart;
	
	/**
	 * La requête sql de test de la base de données.
	 */
	private String sqlTestQuery;

	/**
	 * Le gestionnaire de base de données
	 */
	private DbManager dbManager;

	/**
	 * Le constructeur {@link DatabaseDriverPlugin}.
	 * 
	 * @param name
	 *            Le nom du plugin
	 * @param description
	 *            La description du plugin
	 * @param version
	 *            La version du plugin
	 * @param jarfile
	 *            Le jar associé au plugin
	 * @param driverClass
	 *            Le nom de la classe Driver
	 * @param urlStart
	 *            Le début de l'url
	 * @param dbManager
	 *            Le gestionnaire de base de données
	 */
	public DatabaseDriverPlugin(String name, String description,
			String version, File jarfile, String driverClass, String urlStart,
			String sqlTestQuery, DbManager dbManager) {
		super(name, description, version, PluginType.DATABASE_DRIVER, jarfile);
		this.driverClass = driverClass;
		this.urlStart = urlStart;
		this.dbManager = dbManager;
		this.sqlTestQuery = sqlTestQuery;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eucalyptus.analysesi.plugin.Plugin#load()
	 */
	@Override
	public void load() throws PluginException {
		try {
			JarFileLoader jarFileLoader = new JarFileLoader();
			jarFileLoader.addFile(this.getJarfile());
			Class<?> driver = jarFileLoader.loadClass(driverClass);

			// Ajout du driver Jdbc
			dbManager.addJdbcDriver(driver, urlStart, sqlTestQuery);
		} catch (Exception e) {
			throw new PluginException(e);
		}
	}
}
