/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.plugin;

import java.util.HashMap;
import java.util.Map;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * Le handler qui parse le fichier descripteur.
 * 
 * @author Loic Dreux
 */
class DescriptorHandler extends DefaultHandler {
	/**
	 * La chaine courante.
	 */
	private String currentString;

	/**
	 * Le nom du plugin.
	 */
	private String name;

	/**
	 * La description du plugin.
	 */
	private String description;

	/**
	 * Le type du plugin.
	 */
	private PluginType type;

	/**
	 * La version du plugin.
	 */
	private String version;

	/**
	 * Le nom du fichier jar.
	 */
	private String jarfile;

	/**
	 * Les différentes propriétés
	 */
	private Map<String, String> properties;

	/**
	 * Le constructeur de {@link DescriptorHandler}.
	 */
	public DescriptorHandler() {
		this.properties = new HashMap<String, String>();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.xml.sax.helpers.DefaultHandler#characters(char[], int, int)
	 */
	@Override
	public void characters(char buf[], int offset, int len) throws SAXException {
		currentString = new String(buf, offset, len);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.xml.sax.helpers.DefaultHandler#startElement(java.lang.String,
	 *      java.lang.String, java.lang.String, org.xml.sax.Attributes)
	 */
	@Override
	public void startElement(String uri, String localName, String qName,
			Attributes attributes) {
		if (qName.equals("property")) {
			this.properties.put(
					attributes.getValue(attributes.getIndex("key")), attributes
							.getValue(attributes.getIndex("value")));
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.xml.sax.helpers.DefaultHandler#endElement(java.lang.String,
	 *      java.lang.String, java.lang.String)
	 */
	@Override
	public void endElement(String uri, String localName, String qName)
			throws SAXException {
		if (qName.equals("name")) {
			this.name = currentString;
		} else if (qName.equals("description")) {
			this.description = currentString;
		} else if (qName.equals("version")) {
			this.version = currentString;
		} else if (qName.equals("type")) {
			try {
				this.type = PluginType.valueOf(currentString);
			} catch (IllegalArgumentException e) {
				this.type = null;
			}
		} else if (qName.equals("jar")) {
			this.jarfile = currentString;
		}
	}

	/**
	 * Retourne le nom du fichier jar.
	 * 
	 * @return the jarfile
	 */
	public String getJarfile() {
		return this.jarfile;
	}

	/**
	 * Retourne le nom du plugin.
	 * 
	 * @return le nom du plugin
	 */
	public String getName() {
		return this.name;
	}

	/**
	 * Retourne le type du plugin.
	 * 
	 * @return le type du plugin
	 */
	public PluginType getType() {
		return this.type;
	}

	/**
	 * Retourne le numéro de version.
	 * 
	 * @return the version
	 */
	public String getVersion() {
		return this.version;
	}

	/**
	 * Retourne une propriété.
	 * 
	 * @return une propriété
	 */
	public String getProperty(String key) {
		return properties.get(key);
	}

	/**
	 * Retourne la description.
	 * 
	 * @return la description
	 */
	public String getDescription() {
		return description;
	}
}