/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.plugin;

import java.io.File;
import java.util.Collection;
import java.util.List;

/**
 * Le gestionnaire de plugin.
 *
 * @author Loic Dreux
 */
public interface PluginManager {
	/**
	 * Charge les plugins.
	 * @param folders Les répertoires contenant les plugins
	 */
	public void loadPlugins(List<File> folders);
	
	/**
	 * Retourne la liste des plugins installés
	 * @return la liste des plugins intallésilefilter
	 */
	public List<Plugin> getInstalledPlugins();
	
	/**
	 * Retourne la liste des plugins installables.
	 * @return la liste des plugins installables
	 */
	public List<Plugin> getAvailablePlugins();
	
	/**
	 * Supprime un plugin.
	 * @param plugin Le plugin a supprimer
	 */
	public void removePlugin(Plugin plugin);
	
	/**
	 * Retourne le {@link ClassLoader} associé au plugin.
	 * @param plugin un plugin
	 * @return le classloader associé au plugin
	 */
	public ClassLoader getClassLoader(Plugin plugin);
	
	/**
	 * Retourne la liste des {@link ClassLoader}.
	 * @return la liste des classloader
	 */
	public Collection<ClassLoader> getClassLoaders();
}
