/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.reverse;

import org.eucalyptus.analysesi.db.DbConnectionParameters;
import org.eucalyptus.analysesi.model.MeriseModel;

/**
 * Un {@link ReverseEngine} permet de créer un modèle merise AnalyseSI à partir
 * d'une base de données existante.
 * 
 * @author Loic Dreux
 */
public interface ReverseEngine {
	/**
	 * Créer un modèle merise AnalyseSI à partir d'une base de données existante.
	 * 
	 * @param connectionParameters Les paramètres à la connection Jdbc
	 * @param meriseModel Le modèle à modifier
	 * @return Un modèle merise AnalyseSI
	 */
	public void reverse(DbConnectionParameters connectionParameters, MeriseModel meriseModel) throws ReverseException;
	
	/**
	 * Retourne le nom du moteur dans la locale par défaut.
	 * @return le no mdu moteur
	 */
	public String getLocalizeName();
	
	/**
	 * Retourne le nom du moteur.
	 * @return le nom du moteur
	 */
	public String getName();
}
