/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.save;

import java.io.File;

/**
 * Un format de fichier AnalyseSI.
 *
 * @author Loic Dreux
 */
public interface Format {
	/**
	 * Sauvegarde le model dans un fichier.
	 * @param analyseSIModel le model à sauvegarder
	 * @param file le fichier de sortie
	 */
	public void saveModel(AnalyseSIModel analyseSIModel, File file) throws SaveModelException, SaveModelNotSupportedException;
	
	/**
	 * Charge un model à partir d'un fichier.
	 * @param file le fichier qui contient le model
	 * @return le model
	 */
	public AnalyseSIModel loadModel(File file) throws LoadModelException, LoadModelNotSupportedException;
	
	/**
	 * Retourne l'extension de fichier du format.
	 * @return l'extension de fichier du format
	 */
	public String getFileExtension();
	
	/**
	 * Retourne le nom du format.
	 * @return le nom du format
	 */
	public String getName();
	
	/**
	 * Retourna la description du format.
	 * @return la description du format
	 */
	public String getDescription();
}