/*
 * Copyright AnalyseSI, 2008
 * 
 * Loic DREUX
 * 
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA 
 * sur le site "http://www.cecill.info".
 * 
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * 
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant 
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à 
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement, 
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité. 
 * 
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez 
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */
package org.eucalyptus.analysesi.save;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipException;
import java.util.zip.ZipFile;
import java.util.zip.ZipOutputStream;

import org.eucalyptus.analysesi.model.MeriseModel;

import com.thoughtworks.xstream.XStream;

/**
 * Le format par défaut d'AnalyseSI Eucalyptus.
 * 
 * @author Loic Dreux
 */
public class HibiscusFormat extends AbstractFormat {

	/**
	 * Le constructeur de la classe {@link HibiscusFormat}.
	 */
	public HibiscusFormat() {
		super("AnalyseSI Hibiscus Format",
				"Le format par défaut d'AnalyseSI Hibiscus", "xeaf");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eucalyptus.analysesi.save.Format#loadModel(java.io.File)
	 */
	@Override
	public AnalyseSIModel loadModel(File file) throws LoadModelException, LoadModelNotSupportedException {
		try {
			// Création de l'objet XStream
			XStream xstream = new XStream();
			
			// Ouverture du fichier zip
			ZipFile zipFile = new ZipFile(file);
			ZipEntry zipEntry = zipFile.getEntry("meriseModel.xml"); 
			
			// Ecriture du fichier meriseModel.xml
			final MeriseModel meriseModel = (MeriseModel)xstream.fromXML(zipFile.getInputStream(zipEntry));
			
			// Fermeture du fichier zip
			zipFile.close();
			
			// On retourne le résultat
			return new AnalyseSIModel() {
				/* (non-Javadoc)
				 * @see org.eucalyptus.analysesi.save.AnalyseSIModel#getMeriseModel()
				 */
				@Override
				public MeriseModel getMeriseModel() {
					return meriseModel;
				}
			};
		} catch (ZipException e) {
			throw new LoadModelException(e.getMessage(), e);
		} catch (IOException e) {
			throw new LoadModelException(e.getMessage(), e);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eucalyptus.analysesi.save.Format#saveModel(org.eucalyptus.analysesi
	 * .model.MeriseModel, java.io.File)
	 */
	@Override
	public void saveModel(AnalyseSIModel analyseSIModel, File file) throws SaveModelException, SaveModelNotSupportedException  {
		// Déclaration des flux
		ZipOutputStream zipOutputStream = null;
		
		// Vérification des données
		if (analyseSIModel.getMeriseModel() == null)
			throw new NullPointerException("MeriseModel cannot be null");
		
		try {
			// Création de l'objet XStream
			XStream xstream = new XStream();
			
			// Création du fichier zip
			zipOutputStream = new ZipOutputStream(new FileOutputStream(file));
			zipOutputStream.putNextEntry(new ZipEntry("meriseModel.xml"));
			
			// Ecriture du fichier meriseModel.xml
			xstream.toXML(analyseSIModel.getMeriseModel(), zipOutputStream);
			zipOutputStream.closeEntry();
			
			// Fermeture du flux zip
			zipOutputStream.close();
		} 
		// Gestion des exceptions
		catch (IOException e) {
			throw new SaveModelException(e.getMessage(), e);
		} finally {
			try {
				if (zipOutputStream != null)
					zipOutputStream.close();
			} catch (IOException e) {}
		}
	}
}
